"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _noop = _interopRequireDefault(require("lodash/noop"));
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _index = _interopRequireDefault(require("../divider/index.js"));
var _index2 = require("../helpers/index.js");
var _index3 = require("../hooks/index.js");
var _index4 = _interopRequireDefault(require("../theme/index.js"));
var _style = require("./style.js");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Cell 单元格
 * @description 单元格为列表中的单个展示项。
 */const Cell = ({
  theme,
  innerStyle,
  title,
  titleStyle,
  titleTextStyle,
  titleExtra,
  value,
  valueStyle,
  valueTextStyle,
  valueExtra,
  extra,
  extraTextStyle,
  contentStyle,
  divider = true,
  dividerLeftGap,
  dividerRightGap,
  isLink = false,
  onPressLink,
  center = false,
  arrowDirection = 'right',
  required = false,
  vertical = false,
  valueTextNumberOfLines,
  titleTextNumberOfLines,
  textAlign = 'right',
  onPressDebounceWait = 0,
  // 原生组件属性
  underlayColor,
  style,
  ...restProps
}) => {
  const [CV, STYLES] = _index4.default.useStyle({
    varCreator: _style.varCreator,
    styleCreator: _style.styleCreator,
    theme
  });
  const {
    run: runOnPress
  } = (0, _index3.useDebounceFn)(restProps.onPress || _noop.default, {
    wait: onPressDebounceWait,
    leading: true,
    trailing: false
  });

  // 一定要绑定 Press 事件才有这个效果
  underlayColor = (0, _index2.getDefaultValue)(underlayColor, CV.cell_active_color);
  dividerLeftGap = (0, _index2.getDefaultValue)(dividerLeftGap, CV.cell_group_title_padding_horizontal);
  dividerRightGap = (0, _index2.getDefaultValue)(dividerRightGap, CV.cell_group_title_padding_horizontal);
  if (vertical) {
    textAlign = 'left';
  }
  const centerStyle = center ? {
    alignSelf: 'center'
  } : {};
  const requiredJSX = required ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: STYLES.title_required,
    testID: "CELL_REQUIRED",
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: STYLES.title_required_text,
      children: "*"
    })
  }) : null;
  const titleJSX = (0, _index2.renderTextLikeJSX)(title, [STYLES.title_text, titleTextStyle], {
    numberOfLines: titleTextNumberOfLines
  });
  const valueJSX = (0, _index2.renderTextLikeJSX)(value, [STYLES.value_text, {
    textAlign
  }, valueTextStyle], {
    numberOfLines: valueTextNumberOfLines
  });
  const extraJSX = (0, _index2.renderTextLikeJSX)(extra, [STYLES.extra_text, extraTextStyle]);
  const IconArrow = (0, _index2.getArrowOutline)(arrowDirection);
  const linkJSX = isLink ? /*#__PURE__*/(0, _jsxRuntime.jsx)(IconArrow, {
    testID: "CELL_LINK_ARROW",
    size: CV.cell_icon_size,
    color: CV.cell_icon_color,
    onPress: onPressLink,
    style: STYLES.icon_link
  }) : null;
  const ctxJSX = /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [STYLES.value, valueJSX ? STYLES.hasValue : undefined, centerStyle, valueStyle],
      children: valueJSX
    }), valueExtra, linkJSX]
  });
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableHighlight, {
    ...restProps,
    underlayColor: underlayColor,
    style: [STYLES.cell, style],
    onPress: restProps.onPress ? onPressDebounceWait ? runOnPress : restProps.onPress : undefined,
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
        style: [STYLES.cell_inner, vertical ? null : STYLES.cell_inner_row, extra ? STYLES.cell_inner_has_extra : null, innerStyle],
        children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
          style: [STYLES.title, centerStyle, titleStyle],
          children: [requiredJSX, titleExtra, titleJSX]
        }), vertical ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
          style: [STYLES.content, contentStyle],
          children: ctxJSX
        }) : ctxJSX]
      }), extraJSX, divider ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.default, {
        style: {
          marginLeft: dividerLeftGap,
          marginRight: dividerRightGap
        }
      }) : null]
    })
  });
};
var _default = exports.default = /*#__PURE__*/(0, _react.memo)(Cell);
//# sourceMappingURL=cell.js.map