"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _isUndefined = _interopRequireDefault(require("lodash/isUndefined"));
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _index = _interopRequireDefault(require("../card/index.js"));
var _index2 = _interopRequireDefault(require("../cell/index.js"));
var _index3 = _interopRequireDefault(require("../divider/index.js"));
var _index4 = require("../helpers/index.js");
var _index5 = require("../hooks/index.js");
var _index6 = _interopRequireDefault(require("../theme/index.js"));
var _style = require("./style.js");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Collapse 折叠面板
 */const Collapse = ({
  children,
  theme,
  title,
  titleStyle,
  titleTextStyle,
  iconStyle,
  iconColor,
  iconSize,
  bodyStyle,
  renderTitle,
  renderTitleExtra,
  renderBody,
  type = 'cell',
  onAnimationEnd,
  bodyPadding = true,
  headerDivider = true,
  bodyDivider,
  lazyRender = true,
  square = true,
  testID,
  ...restProps
}) => {
  const [CV, STYLES] = _index6.default.useStyle({
    varCreator: _style.varCreator,
    styleCreator: _style.styleCreator,
    theme
  });
  bodyDivider = (0, _index4.getDefaultValue)(bodyDivider, type === 'cell');
  const [collapse, onCollapse] = (0, _index5.useControllableValue)(restProps, {
    defaultValuePropName: 'defaultCollapse',
    valuePropName: 'collapse',
    trigger: 'onCollapse',
    defaultValue: false
  });
  const onAnimationEndPersistFn = (0, _index5.usePersistFn)(v => {
    onAnimationEnd?.(v);
  });
  /** 记录当前是否可见，在不断 onLayout 的时候可以有一个判断的依据 */
  const Visible = (0, _react.useRef)(collapse);
  const BodyHeight = (0, _react.useRef)(0);
  const MountedRef = (0, _react.useRef)(false);
  const AnimatedValue = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  const toggleBody = (0, _react.useCallback)((v, immediately) => {
    const action = _reactNative.Animated.timing(AnimatedValue, {
      toValue: v ? BodyHeight.current : 0,
      duration: immediately ? 0 : CV.collapse_transition_duration,
      useNativeDriver: false,
      easing: v ? _index4.easing.easeOutCirc : _index4.easing.easeInCubic
    });
    action.start(({
      finished
    }) => {
      if (finished) {
        onAnimationEndPersistFn(v);
      }
    });
  }, [AnimatedValue, onAnimationEndPersistFn, CV.collapse_transition_duration]);

  // 初始化好组件
  (0, _react.useEffect)(() => {
    MountedRef.current = true;
  }, []);
  (0, _react.useEffect)(() => {
    // 同步当前的状态
    Visible.current = collapse;
    toggleBody(collapse, false);
  }, [collapse, toggleBody]);
  const onPressTitle = (0, _react.useCallback)(() => {
    onCollapse(!Visible.current);
  }, [onCollapse]);
  const onLayoutBody = (0, _react.useCallback)(e => {
    // 有点疑惑，折叠的过程中，高度在动态变化，通过 absolute 布局解决无法完全渲染
    BodyHeight.current = e.nativeEvent.layout.height;
    // 展开的过程中才会存在动态高度
    if (Visible.current) {
      // 当收齐的时候已知高度
      toggleBody(Visible.current, Visible.current);
    }
  }, [toggleBody]);
  const ArrowOutline = (0, _index4.getArrowOutline)(collapse ? 'up' : 'down');
  const arrowJSX = /*#__PURE__*/(0, _jsxRuntime.jsx)(ArrowOutline, {
    style: iconStyle,
    color: !(0, _isUndefined.default)(iconColor) ? iconColor : CV.collapse_icon_color,
    size: !(0, _isUndefined.default)(iconSize) ? iconSize : CV.collapse_icon_size
  });
  const titleJSX = renderTitle ? renderTitle(collapse) : title;
  const titleExtraJSX = renderTitleExtra ? renderTitleExtra(collapse, arrowJSX) : arrowJSX;
  const bodyJSX = lazyRender && !MountedRef.current && !collapse ? null : renderBody ? renderBody() : children;
  const ctxJSX = /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Animated.View, {
    style: [STYLES.collapse, {
      height: AnimatedValue
    }],
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      collapsable: false,
      style: STYLES.body,
      onLayout: onLayoutBody,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: [bodyPadding ? STYLES.body_padding : undefined, bodyStyle],
        children: bodyJSX
      }), bodyDivider ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_index3.default, {
        type: "light",
        style: STYLES.divider
      }) : null]
    })
  });
  if (type === 'card') {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.default, {
      square: square,
      title: titleJSX,
      extra: titleExtraJSX,
      headerDivider: headerDivider,
      titleStyle: titleStyle,
      titleTextStyle: titleTextStyle,
      bodyPadding: false,
      onPressHeader: onPressTitle,
      testID: testID,
      children: ctxJSX
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_index2.default, {
      title: titleJSX,
      style: titleStyle,
      titleTextStyle: titleTextStyle,
      valueExtra: titleExtraJSX,
      onPress: onPressTitle,
      divider: headerDivider,
      testID: testID
    }), ctxJSX]
  });
};
var _default = exports.default = /*#__PURE__*/(0, _react.memo)(Collapse);
//# sourceMappingURL=collapse.js.map