"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _isBoolean = _interopRequireDefault(require("lodash/isBoolean"));
var _isNil = _interopRequireDefault(require("lodash/isNil"));
var _react = require("react");
var _reactNative = require("react-native");
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _index = _interopRequireDefault(require("../divider/index.js"));
var _index2 = require("../helpers/index.js");
var _index3 = _interopRequireDefault(require("../theme/index.js"));
var _style = require("./style.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const FloatingPanel = ({
  theme,
  anchorStart,
  anchorEnd,
  title,
  titleDivider = true,
  offsetThreshold = 0.2,
  zIndex = 10,
  draggingOnContent = true,
  onAnimationEnd,
  _onMoveShouldSetPanResponder,
  children,
  ...restProps
}) => {
  const insets = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  const {
    height
  } = (0, _reactNative.useWindowDimensions)();
  const [CV, STYLES] = _index3.default.useStyle({
    varCreator: _style.varCreator,
    styleCreator: _style.styleCreator,
    theme
  });
  const hasTitle = !(0, _isNil.default)(title);
  const _anchorStart = (0, _index2.getDefaultValue)(anchorStart, insets.bottom + CV.floating_panel_header_padding * 2 + (hasTitle ? CV.floating_panel_header_text_font_size : 0));
  const _anchorEnd = (0, _index2.getDefaultValue)(anchorEnd, height - insets.top);
  const yMax = _anchorEnd - _anchorStart;
  const yMin = 0;
  const PanAnimated = (0, _react.useRef)(new _reactNative.Animated.Value(yMax));
  const Anchor = (0, _react.useRef)(_anchorEnd - _anchorStart);
  const panResponder = (0, _react.useMemo)(() => {
    return _reactNative.PanResponder.create({
      onMoveShouldSetPanResponder: (_, gestureState) => {
        const stop = _onMoveShouldSetPanResponder?.(_, gestureState);
        if ((0, _isBoolean.default)(stop)) {
          return stop;
        }
        if (Anchor.current === yMin && gestureState.dy < 0) {
          return false;
        }
        return true;
      },
      onPanResponderMove: (e, gestureState) => {
        let newValue = Anchor.current + gestureState.dy;
        if (newValue > yMax) {
          newValue = yMax;
          e.stopPropagation();
        }
        if (newValue < yMin) {
          newValue = yMin;
          e.stopPropagation();
        }
        PanAnimated.current.setValue(newValue);
      },
      onPanResponderRelease: (_, gestureState) => {
        const triggered = Math.abs(gestureState.dy) >= _anchorEnd * offsetThreshold;
        const newValue = triggered ? gestureState.dy < 0 ? yMin : yMax : Anchor.current;
        _reactNative.Animated.timing(PanAnimated.current, {
          toValue: newValue,
          // 设置动画的属性值
          useNativeDriver: true,
          duration: 200
        }).start(({
          finished
        }) => {
          if (finished) {
            Anchor.current = newValue;
            onAnimationEnd?.(newValue === yMin);
          }
        });
      }
    });
  }, [_anchorEnd, _onMoveShouldSetPanResponder, offsetThreshold, onAnimationEnd, yMax]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Animated.View, {
    ...restProps,
    ...(draggingOnContent ? panResponder.panHandlers : undefined),
    style: [STYLES.floatingPanel, {
      zIndex,
      height: _anchorEnd,
      transform: [{
        translateY: PanAnimated.current
      }]
    }, restProps.style],
    children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: STYLES.header,
      ...(!draggingOnContent ? panResponder.panHandlers : undefined),
      children: [(0, _index2.renderTextLikeJSX)(title, STYLES.headerText), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: STYLES.indicator
      })]
    }), titleDivider ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.default, {}) : null, children]
  });
};
var _default = exports.default = /*#__PURE__*/(0, _react.memo)(FloatingPanel);
//# sourceMappingURL=floating-panel.js.map