"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _usePersistFn = _interopRequireDefault(require("./usePersistFn.js"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function useControllableValue(props = {}, options = {}) {
  const {
    defaultValue,
    defaultValuePropName = 'defaultValue',
    valuePropName = 'value',
    trigger = 'onChange'
  } = options;
  const value = props[valuePropName];
  const isControlled = valuePropName in props;
  const [localValue, setLocalValue] = (0, _react.useState)(() => {
    if (isControlled) {
      return value;
    }
    if (defaultValuePropName in props) {
      return props[defaultValuePropName];
    }
    return defaultValue;
  });
  const setState = (v, ...args) => {
    if (!isControlled) {
      setLocalValue(v);
    }
    if (props[trigger]) {
      props[trigger](v, ...args);
    }
  };
  return [isControlled ? value : localValue, (0, _usePersistFn.default)(setState)];
}
var _default = exports.default = useControllableValue;
//# sourceMappingURL=useControllableValue.js.map