"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _isUndefined = _interopRequireDefault(require("lodash/isUndefined"));
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _index = require("../helpers/index.js");
var _index2 = _interopRequireDefault(require("../theme/index.js"));
var _style = require("./style.js");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Overlay 遮罩层
 * @description 创建一个遮罩层，用于强调特定的页面元素，并阻止用户进行其他操作。
 * TODO 统计遮罩层数量，动态控制状态栏的颜色，避免黑色遮罩层配合黑色文字的状态栏。
 */const Overlay = ({
  testID,
  children,
  theme,
  style,
  overlayStyle,
  zIndex,
  visible = false,
  duration,
  onPress,
  onRequestClose,
  backgroundColor
}) => {
  const [CV,, TOKENS] = _index2.default.useStyle({
    varCreator: _style.varCreator,
    theme
  });
  const fadeAnim = (0, _react.useRef)(new _reactNative.Animated.Value(0));
  const fadeInstance = (0, _react.useRef)(null);
  const [localVisible, setLocalVisible] = (0, _react.useState)(visible);
  duration = (0, _index.getDefaultValue)(duration, TOKENS.animation_duration_base);
  backgroundColor = (0, _index.getDefaultValue)(backgroundColor, CV.overlay_background_color);

  // 监听状态变化，执行动画
  (0, _react.useEffect)(() => {
    if (visible) {
      setLocalVisible(true);
    }
    fadeInstance.current = _reactNative.Animated.timing(fadeAnim.current,
    // 动画中的变量值
    {
      toValue: visible ? 1 : 0,
      duration: duration,
      useNativeDriver: true
    });
    fadeInstance.current.start(({
      finished
    }) => {
      if (finished) {
        fadeInstance.current = null;
        if (!visible) {
          setLocalVisible(false);
        }
      }
    });
    return () => {
      // 停止动画
      if (fadeInstance.current) {
        fadeInstance.current.stop();
        fadeInstance.current = null;
      }
    };
  }, [visible, duration]);

  // Android 返回按钮
  (0, _react.useEffect)(() => {
    const backHandler = _reactNative.BackHandler.addEventListener('hardwareBackPress', () => {
      if (typeof onRequestClose === 'function' && visible) {
        return onRequestClose();
      }
      return false;
    });
    return () => backHandler.remove();
  }, [visible, onRequestClose]);
  if (!localVisible) {
    // TODO 优化文档报错
    // 直接返回 null dumi 报错 -、-
    // eslint-disable-next-line react/jsx-no-useless-fragment
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {});
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Animated.View, {
    testID: testID,
    style: [STYLES.overlay, localVisible ? STYLES.overlay_active : null, {
      opacity: fadeAnim.current,
      backgroundColor: backgroundColor,
      zIndex: !(0, _isUndefined.default)(zIndex) ? zIndex : CV.overlay_z_index
    }, overlayStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
      style: [STYLES.touchable, style],
      activeOpacity: 1,
      onPress: onPress,
      children: children
    })
  });
};
const STYLES = _reactNative.StyleSheet.create({
  overlay: {
    position: 'relative',
    left: 0,
    right: 0,
    top: 0,
    bottom: 0
  },
  overlay_active: {
    position: 'absolute'
  },
  touchable: {
    flex: 1
  }
});
var _default = exports.default = /*#__PURE__*/(0, _react.memo)(Overlay);
//# sourceMappingURL=overlay.js.map