"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _noop = _interopRequireDefault(require("lodash/noop"));
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var helpers = _interopRequireWildcard(require("../helpers/index.js"));
var _index2 = require("../hooks/index.js");
var _useStateUpdate = _interopRequireDefault(require("../hooks/useStateUpdate.js"));
var _overlay = _interopRequireDefault(require("../overlay/overlay.js"));
var _index3 = _interopRequireDefault(require("../theme/index.js"));
var _helper = require("./helper.js");
var _style = require("./style.js");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Popup 弹出层
 * @description 弹出层容器，用于展示弹窗、信息提示等内容，支持多个弹出层叠加展示。
 */const Popup = ({
  children,
  style,
  theme,
  visible = false,
  overlay = true,
  duration,
  closeOnPressOverlay = true,
  position = 'center',
  round = false,
  safeAreaInsetBottom = false,
  safeAreaInsetTop = false,
  lazyRender = true,
  destroyOnClosed = false,
  onPressOverlay: onPressOverlayFn,
  onOpen: onOpenFn,
  onOpened: onOpenedFn,
  onClose: onCloseFn,
  onClosed: onClosedFn,
  onRequestClose,
  overlayBackgroundColor
}) => {
  const insets = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  const onPressOverlayPersistFn = (0, _index2.usePersistFn)(onPressOverlayFn || _noop.default);
  const onOpenPersistFn = (0, _index2.usePersistFn)(onOpenFn || _noop.default);
  const onOpenedPersistFn = (0, _index2.usePersistFn)(onOpenedFn || _noop.default);
  const onClosePersistFn = (0, _index2.usePersistFn)(onCloseFn || _noop.default);
  const onClosedPersistFn = (0, _index2.usePersistFn)(onClosedFn || _noop.default);
  const [CV, STYLES, TOKENS] = _index3.default.useStyle({
    varCreator: _style.varCreator,
    styleCreator: _style.styleCreator,
    theme
  });
  duration = helpers.getDefaultValue(duration, TOKENS.animation_duration_base);
  const [state, setState] = (0, _useStateUpdate.default)({
    visible,
    // 遮罩层显示、隐藏单独管理，避免弹出层完成后才触发关闭，两个组件应该同时变化
    overlayVisible: visible,
    zIndex: helpers.getNextZIndex(),
    lazyRender
  });
  const MountedRef = (0, _react.useRef)(false);
  const fadeAnim = (0, _react.useRef)(new _reactNative.Animated.Value((0, _helper.getPosition)(visible, position))).current;
  const fadeInstance = (0, _react.useRef)(null);

  /** 点击遮罩层 */
  const onPressOverlay = (0, _react.useCallback)(() => {
    if (closeOnPressOverlay) {
      // 关闭弹层
      onPressOverlayPersistFn();
    }
  }, [closeOnPressOverlay, onPressOverlayPersistFn]);

  // 监听状态变化，执行动画
  (0, _react.useEffect)(() => {
    if (visible) {
      // 弹出弹出，立即响应
      setState({
        visible,
        zIndex: helpers.getNextZIndex(),
        lazyRender: false
      });
    }

    // 遮罩层状态实时显示
    setState({
      overlayVisible: visible
    });
    if (MountedRef.current) {
      fadeAnim.setValue((0, _helper.getPosition)(!visible, position));
      if (visible) {
        onOpenPersistFn();
      } else {
        onClosePersistFn();
      }
      fadeInstance.current = _reactNative.Animated.timing(fadeAnim,
      // 动画中的变量值
      {
        toValue: (0, _helper.getPosition)(visible, position),
        duration: duration,
        useNativeDriver: true,
        easing: visible ? helpers.easing.easeOutCirc : helpers.easing.easeInCubic
      });
      fadeInstance.current.start(({
        finished
      }) => {
        if (finished) {
          fadeInstance.current = null;
          if (!visible) {
            setState({
              visible,
              lazyRender: destroyOnClosed
            });
            onClosedPersistFn();
          } else {
            onOpenedPersistFn();
          }
        }
      });
    }
    return () => {
      // 停止动画
      if (fadeInstance.current) {
        fadeInstance.current.stop();
        fadeInstance.current = null;
      }
    };
  }, [destroyOnClosed, duration, fadeAnim, position, onClosedPersistFn, onClosePersistFn, onOpenedPersistFn, onOpenPersistFn, visible]);

  // 初始化好组件
  (0, _react.useEffect)(() => {
    MountedRef.current = true;
  }, []);

  // Android 返回按钮
  (0, _react.useEffect)(() => {
    const backHandler = _reactNative.BackHandler.addEventListener('hardwareBackPress', () => {
      if (typeof onRequestClose === 'function' && visible) {
        return onRequestClose();
      }
      return false;
    });
    return () => backHandler.remove();
  }, [onRequestClose, visible]);
  const popupStyles = [STYLES.popup, (0, _style.getBorderRadius)(CV, position, round), {
    paddingBottom: state.visible && safeAreaInsetBottom ? insets.bottom : 0,
    paddingTop: state.visible && safeAreaInsetTop ? insets.top : 0,
    zIndex: state.zIndex
  }, style, state.visible ? [STYLES.popup_active, (0, _helper.getTransform)(position, fadeAnim), _style.PopupPositionMap[position]] : STYLES.popup_hide];
  if (state.lazyRender) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [overlay ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_overlay.default, {
      visible: state.overlayVisible,
      zIndex: state.zIndex,
      duration: duration,
      onPress: onPressOverlay,
      backgroundColor: overlayBackgroundColor
    }) : null, /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Animated.View, {
      style: popupStyles,
      pointerEvents: position !== 'center' ? undefined : 'box-none',
      children: children
    })]
  });
};
var _default = exports.default = /*#__PURE__*/(0, _react.memo)(Popup);
//# sourceMappingURL=popup.js.map