"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _omit = _interopRequireDefault(require("lodash/omit"));
var _pick = _interopRequireDefault(require("lodash/pick"));
var _react = _interopRequireWildcard(require("react"));
var _index = _interopRequireDefault(require("../button/index.js"));
var _index2 = _interopRequireDefault(require("../button-bar/index.js"));
var _index3 = require("../hooks/index.js");
var _index4 = _interopRequireDefault(require("../locale/index.js"));
var _popup = _interopRequireDefault(require("../popup/popup.js"));
var _popupHeader = _interopRequireDefault(require("../popup/popup-header.js"));
var _popupPage = _interopRequireDefault(require("../popup/popup-page.js"));
var _index5 = _interopRequireDefault(require("../tree/index.js"));
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const treePropsField = ['multiple', 'multipleMode', 'value', 'defaultValue', 'onChange', 'options', 'renderSwitcherIcon', 'indent', 'activeColor', 'defaultExpandedValues', 'defaultExpandAll', 'search', 'onSearch', 'placeholder', 'minHeight', 'cancellable'];

/**
 * Selector 弹出层式 Select
 * @description 类似 Web 端的 Select 组件，可以多选、单选。
 */
const Selector = ({
  title,
  onChangeImmediate,
  safeAreaInsetTop,
  confirmButtonText,
  // popup 组件相关属性
  visible,
  closeOnPressOverlay = true,
  onClose,
  ...restProps
}) => {
  const treeProps = (0, _pick.default)(restProps, treePropsField);
  const popupProps = (0, _omit.default)(restProps, treePropsField);
  const isMultiple = treeProps.multiple;
  const safeHeight = (0, _index3.useSafeHeight)({
    top: safeAreaInsetTop,
    bottom: false
  });
  const locale = _index4.default.useLocale().Selector;
  // const [valueMultiple, onChangeMultiple] = useControllableValue<
  //   SelectorValue[]
  // >(omit(restProps, 'onChange'), {
  //   defaultValue: Array.isArray(treeProps.value)
  //     ? treeProps.value
  //     : Array.isArray(treeProps.defaultValue)
  //     ? treeProps.defaultValue
  //     : [],
  // })
  const [valueMultiple, setValueMultiple] = (0, _react.useState)(Array.isArray(treeProps.value) ? treeProps.value : Array.isArray(treeProps.defaultValue) ? treeProps.defaultValue : []);

  // 同步外面的数据
  (0, _index3.useUpdateEffect)(() => {
    if (treeProps.multiple) {
      setValueMultiple(treeProps.value);
    }
  }, [treeProps.multiple, treeProps.value]);
  const onChangeMultiplePersistFn = (0, _index3.usePersistFn)(v => {
    if (onChangeImmediate) {
      setValueMultiple(onChangeImmediate(v));
    } else {
      setValueMultiple(v);
    }
  });

  /**
   * 点击确定按钮
   */
  const onPressOk = (0, _index3.usePersistFn)(() => {
    const _onChange = treeProps.onChange;
    _onChange?.(valueMultiple, valueMultiple.map(i => _index5.default.findNodeByValue(treeProps.options, i)));
  });
  const contentJSX = /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_popupHeader.default, {
      title: title ?? locale.title,
      onClose: onClose
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index5.default, {
      ...treeProps,
      value: isMultiple ? valueMultiple : treeProps.value ?? treeProps.defaultValue,
      onChange: isMultiple ? onChangeMultiplePersistFn : treeProps.onChange
    }), treeProps.multiple ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_index2.default, {
      alone: true,
      divider: false,
      height: 60,
      safeAreaInsetBottom: false,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.default, {
        type: "primary",
        onPress: onPressOk,
        text: confirmButtonText ?? locale.confirmButtonText
      })
    }) : null]
  });
  if (treeProps.search) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_popupPage.default, {
      ...popupProps,
      visible: visible,
      onClose: onClose,
      closeOnPressOverlay: closeOnPressOverlay,
      onPressOverlay: onClose,
      round: true,
      safeAreaInsetBottom: true,
      children: contentJSX
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_popup.default, {
    ...popupProps,
    style: {
      maxHeight: safeHeight
    },
    visible: visible,
    onClose: onClose,
    closeOnPressOverlay: closeOnPressOverlay,
    onPressOverlay: onClose,
    position: "bottom",
    round: true,
    safeAreaInsetBottom: true,
    children: contentJSX
  });
};
var _default = exports.default = /*#__PURE__*/(0, _react.memo)(Selector);
//# sourceMappingURL=selector.js.map