"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _isNil = _interopRequireDefault(require("lodash/isNil"));
var _isUndefined = _interopRequireDefault(require("lodash/isUndefined"));
var _noop = _interopRequireDefault(require("lodash/noop"));
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _style = require("../button/style.js");
var _index = require("../helpers/index.js");
var _index2 = require("../hooks/index.js");
var _index3 = _interopRequireDefault(require("../locale/index.js"));
var _index4 = _interopRequireDefault(require("../theme/index.js"));
var _style2 = require("./style.js");
var _textInputClear = _interopRequireDefault(require("./text-input-clear.js"));
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const defaultFormatter = t => t;
let nextInputAccessoryViewID = 0;
const getNextInputAccessoryViewID = () => ++nextInputAccessoryViewID;
const iOSPlatform = _reactNative.Platform.OS === 'ios';

/**
 * 自定义输入项
 * @description 在和 react-native-keyboard-aware-scroll-view 配合做软键盘适配时，如果是 textarea 类型默认 scrollEnabled 禁用，避免软键盘遮挡输入内容
 * @description 动态切换输入内容可见，请手动控制 secureTextEntry，如果只是切换 type 在 iOS 正式环境可能会不生效
 */
const TextInput = /*#__PURE__*/(0, _react.forwardRef)(({
  theme,
  addonGroupStyle,
  addonBeforeTextStyle,
  addonAfterTextStyle,
  fixGroupStyle,
  prefixTextStyle,
  suffixTextStyle,
  type = 'text',
  rows = 2,
  clearable = false,
  clearTrigger = 'focus',
  formatter,
  formatTrigger = 'onChangeText',
  showWordLimit = false,
  bordered = false,
  addonAfter,
  addonBefore,
  prefix,
  suffix,
  inputWidth,
  size = 'm',
  textareaMaxHeight,
  // TextInput 的属性
  style,
  multiline,
  selectionColor,
  placeholderTextColor,
  onChangeText,
  onEndEditing,
  onFocus,
  onBlur,
  returnKeyType,
  ...resetProps
}, ref) => {
  // 修正数据
  if (type === 'textarea') {
    multiline = true;
    clearable = false;
  } else {
    returnKeyType = (0, _index.getDefaultValue)(returnKeyType, 'done');
  }
  if (showWordLimit && (0, _isUndefined.default)(resetProps.maxLength)) {
    showWordLimit = false;
  }
  const locale = _index3.default.useLocale().TextInput;
  const [CV, STYLES] = _index4.default.useStyle({
    varCreator: _style2.varCreator,
    styleCreator: _style2.styleCreator,
    theme
  });
  const [CV_BUTTON] = _index4.default.useStyle({
    varCreator: _style.varCreator
  });
  const onChangeTextPersistFn = (0, _index2.usePersistFn)(onChangeText || _noop.default);
  const onEndEditingPersistFn = (0, _index2.usePersistFn)(onEndEditing || _noop.default);
  const onFocusPersistFn = (0, _index2.usePersistFn)(onFocus || _noop.default);
  const onBlurPersistFn = (0, _index2.usePersistFn)(onBlur || _noop.default);
  const formatterPersistFn = (0, _index2.usePersistFn)(formatter || defaultFormatter);
  const [value, onChange] = (0, _index2.useControllableValue)(resetProps);
  const [focus, setFocus] = (0, _react.useState)(false);
  const TextInputRef = (0, _react.useRef)(null);
  const colorScheme = (0, _reactNative.useColorScheme)();
  const inputAccessoryViewID = (0, _react.useMemo)(() => `TextInput_${getNextInputAccessoryViewID()}`, []);
  /** 当前值 */
  const Value = (0, _react.useRef)(value);
  Value.current = value;
  /** 显示禁用样子 bordered 才显示 */
  const showDisabledInput = bordered && !(0, _isNil.default)(resetProps.editable) && !resetProps.editable;
  /** 输入框最小高度 */
  const textInputMinHeight = CV[`text_input_${size}_min_height`];
  /** 所有文字/文案相关的大小 */
  const textInputFontSize = CV[`text_input_${size}_font_size`];
  selectionColor = (0, _index.getDefaultValue)(selectionColor, CV.text_input_selection_color);
  placeholderTextColor = (0, _index.getDefaultValue)(placeholderTextColor, CV.text_input_placeholder_text_color);

  // 转发实例
  (0, _react.useImperativeHandle)(ref, () => {
    return TextInputRef.current;
  });

  /** 点击完成收起软键盘 */
  const onPressFinish = (0, _react.useCallback)(() => {
    _reactNative.Keyboard.dismiss();
    setFocus(false);
  }, []);

  /** 点击视觉上的输入框，聚焦，多行文本 */
  const onPressTextInput = (0, _react.useCallback)(() => {
    TextInputRef.current?.focus();
  }, []);

  /**
   * 当文字变化
   * @description 在这个阶段判断字符长度、格式化数据
   */
  const onChangeTextTextInput = (0, _react.useCallback)(t => {
    if (formatTrigger === 'onChangeText') {
      t = formatterPersistFn(t);
    }
    onChange(t);
    onChangeTextPersistFn(t);
  }, [formatTrigger, formatterPersistFn, onChange, onChangeTextPersistFn]);

  /** 编辑结束的时候 */
  const onEndEditingTextInput = (0, _react.useCallback)(e => {
    if (formatTrigger === 'onEndEditing') {
      e.nativeEvent.text = formatterPersistFn(e.nativeEvent.text);
    }
    if (Value.current !== e.nativeEvent.text) {
      onChange(e.nativeEvent.text);
    }
    onEndEditingPersistFn(e);
  }, [onEndEditingPersistFn, formatterPersistFn, formatTrigger, onChange]);

  /** 当文本框内容变化时 */
  const onChangeTextInput = (0, _react.useCallback)(e => {
    onChange(e.nativeEvent.text);
  }, [onChange]);

  /**
   * 点击清除按钮
   * @description 目前不能在输入框聚焦的时候触发点击，输入框失去焦点后才能触发点击，可能是软键盘的问题？
   */
  const onPressClearable = (0, _react.useCallback)(() => {
    TextInputRef.current?.clear();
    onChange('');
    onChangeTextPersistFn('');
    onPressTextInput();
  }, [onChangeTextPersistFn, onPressTextInput, onChange]);

  /** 输入框聚焦 */
  const onFocusTextInput = (0, _react.useCallback)(e => {
    setFocus(true);
    onFocusPersistFn(e);
  }, [onFocusPersistFn]);

  /** 输入框失焦 */
  const onBlurTextInput = (0, _react.useCallback)(e => {
    setFocus(false);
    onBlurPersistFn(e);
  }, [onBlurPersistFn]);
  const textInputTextStyle = {
    fontSize: textInputFontSize
  };
  const isTextarea = type === 'textarea';
  // textarea 模式就是纯输入框
  const addonBeforeJSX = isTextarea ? null : (0, _index.renderTextLikeJSX)(addonBefore, [STYLES.addon_text, STYLES.addon_text_before, textInputTextStyle, addonBeforeTextStyle]);
  const addonAfterJSX = isTextarea ? null : (0, _index.renderTextLikeJSX)(addonAfter, [STYLES.addon_text, STYLES.addon_text_after, textInputTextStyle, addonAfterTextStyle]);
  const prefixJSX = isTextarea ? null : (0, _index.renderTextLikeJSX)(prefix, [STYLES.input_fix_text, STYLES.input_fix_text_pre, textInputTextStyle, prefixTextStyle]);
  const suffixJSX = isTextarea ? null : (0, _index.renderTextLikeJSX)(suffix, [STYLES.input_fix_text, STYLES.input_fix_text_suf, textInputTextStyle, suffixTextStyle]);
  const customTextInputWidthStyle = !(0, _isNil.default)(inputWidth) ? {
    flexShrink: 1,
    flexGrow: 0,
    flexBasis: inputWidth,
    width: inputWidth
  } : {};
  /** 在添加了 addonXxx 的情况下，需要输入框部分自适应宽 */
  const inputAddonModeStyle = {
    flex: 1
  };
  /** 输入框不确定是否要排除边框 */
  const inputUncertainHeight = bordered ? 2 : 0;
  const inputStyles = [STYLES.input, isTextarea ? {
    minHeight: textInputMinHeight * rows - inputUncertainHeight,
    maxHeight: textareaMaxHeight,
    paddingVertical: 2,
    alignItems: 'flex-start'
  } : {
    minHeight: textInputMinHeight - inputUncertainHeight,
    alignContent: 'center'
  }, isTextarea && showWordLimit ? {
    paddingBottom: CV.text_input_word_limit_text_font_size
  } : null, (addonAfterJSX || addonBeforeJSX) && bordered ? inputAddonModeStyle : null, customTextInputWidthStyle];

  /**
   * 显示辅助工具栏
   * @description 单行输入框回车键已具备收起键盘的作用
   */
  const showInputAccessoryView = iOSPlatform && type !== 'text' && ((0, _isNil.default)(resetProps.editable) || !!resetProps.editable);
  const keyboardAppearance = (0, _isUndefined.default)(resetProps.keyboardAppearance) || resetProps.keyboardAppearance === 'default' ? colorScheme || 'light' : resetProps.keyboardAppearance;
  const textInputJSX = /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.TouchableOpacity, {
    activeOpacity: 1,
    style: inputStyles,
    onPress: onPressTextInput,
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TextInput, {
      ...resetProps,
      ref: TextInputRef,
      style: [STYLES.text_input, textInputTextStyle, showDisabledInput ? STYLES.text_input_disabled : null, style],
      placeholder: focus && resetProps.textAlign === 'center' ? undefined : resetProps.placeholder,
      value: value,
      multiline: multiline,
      returnKeyType: returnKeyType,
      selectionColor: selectionColor,
      placeholderTextColor: placeholderTextColor,
      onChangeText: onChangeTextTextInput,
      onEndEditing: onEndEditingTextInput,
      onChange: onChangeTextInput,
      onFocus: onFocusTextInput,
      onBlur: onBlurTextInput,
      inputAccessoryViewID: resetProps.inputAccessoryViewID || (showInputAccessoryView ? inputAccessoryViewID : undefined)
    }), clearable && (clearTrigger === 'focus' ? focus : true) && value && value.length ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_textInputClear.default, {
      theme: theme,
      onPress: onPressClearable
    }) : null, showWordLimit ? /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
      style: STYLES.word_limit_text,
      children: [value?.length || 0, "/", resetProps.maxLength]
    }) : null]
  });
  const inputJSX = /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
    children: [showInputAccessoryView ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.InputAccessoryView, {
      nativeID: inputAccessoryViewID,
      backgroundColor: CV[`text_input_${keyboardAppearance}_accessory_background_color`],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: STYLES.accessory,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
          onPress: onPressFinish,
          activeOpacity: CV_BUTTON.button_active_opacity,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
            style: STYLES.accessory_text,
            children: locale.complete
          })
        })
      })
    }) : null, prefixJSX || suffixJSX || bordered ? /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: [STYLES.input_fix_group, bordered ? [STYLES.input_border, addonAfterJSX || addonBeforeJSX ? inputAddonModeStyle : null, !(0, _isNil.default)(resetProps.editable) && !resetProps.editable ? STYLES.input_disabled : null] : null, prefixJSX || suffixJSX ? null : customTextInputWidthStyle, fixGroupStyle],
      children: [prefixJSX, textInputJSX, suffixJSX]
    }) : textInputJSX]
  });
  if (addonAfterJSX || addonBeforeJSX) {
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: [STYLES.addon_group, addonGroupStyle],
      children: [addonBeforeJSX, inputJSX, addonAfterJSX]
    });
  }
  return inputJSX;
});
var _default = exports.default = /*#__PURE__*/(0, _react.memo)(TextInput);
//# sourceMappingURL=text-input.js.map