"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.success = exports.setDefaultOptions = exports.resetDefaultOptions = exports.loading = exports.fail = exports.Instance = void 0;
var _react = _interopRequireWildcard(require("react"));
var _index = _interopRequireDefault(require("../portal/index.js"));
var _toast = _interopRequireDefault(require("./toast.js"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const parseOptions = message => {
  if (typeof message === 'object') {
    return message;
  }
  return {
    message
  };
};
const defaultOptions = {
  type: 'text',
  duration: 2000,
  message: '',
  position: 'middle',
  forbidPress: false,
  closeOnPressOverlay: false,
  overlay: false,
  loadingType: 'spinner'
};

// eslint-disable-next-line @typescript-eslint/consistent-type-assertions
let defaultOptionsMap = {};
let currentOptions = {
  ...defaultOptions
};
const Instance = options => {
  let opts = typeof options === 'string' ? {
    message: options
  } : options;
  const type = opts.type || currentOptions.type;

  // 合并参数
  opts = {
    ...currentOptions,
    ...(type ? defaultOptionsMap[type] : {}),
    ...opts
  };
  const ToastRef = /*#__PURE__*/(0, _react.createRef)();
  const key = _index.default.add(/*#__PURE__*/(0, _jsxRuntime.jsx)(_toast.default, {
    ...opts,
    ref: ToastRef,
    onClosed: () => {
      _index.default.remove(key);
      opts.onClosed?.();
    }
  }));

  // TODO 优化调用方法
  return {
    close: () => {
      ToastRef.current?.close();
    },
    setMessage: m => {
      ToastRef.current?.setMessage(m);
    }
  };
};
exports.Instance = Instance;
const loading = options => Instance({
  type: 'loading',
  ...parseOptions(options)
});
exports.loading = loading;
const success = options => Instance({
  type: 'success',
  ...parseOptions(options)
});
exports.success = success;
const fail = options => Instance({
  type: 'fail',
  ...parseOptions(options)
});

/**
 * 修改默认配置，对所有 Toast 生效。传入 type 可以修改指定类型的默认配置
 */
exports.fail = fail;
const setDefaultOptions = (type, options) => {
  if (typeof type === 'string') {
    defaultOptionsMap[type] = options;
  } else {
    Object.assign(currentOptions, type);
  }
};

/**
 * 重置默认配置，对所有 Toast 生效。传入 type 可以重置指定类型的默认配置
 */
exports.setDefaultOptions = setDefaultOptions;
const resetDefaultOptions = type => {
  if (typeof type === 'string') {
    defaultOptionsMap[type] = null;
  } else {
    currentOptions = {
      ...defaultOptions
    };
    // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
    defaultOptionsMap = {};
  }
};
exports.resetDefaultOptions = resetDefaultOptions;
//# sourceMappingURL=toast-instance.js.map