"use strict";

import isNil from 'lodash/isNil';
import React, { memo } from 'react';
import { View, Text } from 'react-native';
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";

/**
 * Badge 徽标
 * @description 在右上角展示徽标数字或小红点。
 */
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const Badge = ({
  children,
  theme,
  count,
  dot,
  max,
  color,
  countStyle,
  countTextStyle,
  loading = false,
  showZero = false,
  offset,
  status,
  ...restProps
}) => {
  const TOKENS = Theme.useThemeTokens();
  const CV = Theme.createVar(TOKENS, varCreator);
  const [, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  if (!isNil(max) && typeof count === 'number' && count > max) {
    count = `${max}+`;
  }
  const hasCount = !isNil(count) && (count === 0 ? showZero : true);
  const countStyles = [STYLES.count, {
    backgroundColor: color || CV[`badge_status_${status}`] || CV.badge_background_color
  }, dot ? STYLES.count_dot : null, !isNil(children) ? [STYLES.count_fixed, dot ? STYLES.count_dot_fixed : null, offset ? {
    transform: [{
      translateX: offset[0]
    }, {
      translateY: offset[1]
    }]
  } : null] : [], countStyle];
  const badgeJSX = !loading && (hasCount || dot) ? /*#__PURE__*/_jsx(View, {
    style: countStyles,
    children: dot ? null : /*#__PURE__*/_jsx(Text, {
      style: [STYLES.count_text, countTextStyle],
      children: count
    })
  }) : null;
  return /*#__PURE__*/_jsxs(View, {
    ...restProps,
    collapsable: false,
    children: [badgeJSX, children]
  });
};
export default /*#__PURE__*/memo(Badge);
//# sourceMappingURL=badge.js.map