"use strict";

import omit from 'lodash/omit';
import React from 'react';
import { ScrollView } from 'react-native';
import { useControllableValue } from "../hooks/index.js";
import Space from "../space/index.js";
import ButtonOption from "./button-option.js";
import { jsx as _jsx } from "react/jsx-runtime";
function ButtonOptionGroup({
  theme,
  activeHighlight = true,
  type = 'hazy',
  round = false,
  editable = true,
  scrollable = false,
  deselect = true,
  options,
  multiple,
  ...restProps
}) {
  const [value, onChange] = useControllableValue(restProps, {
    defaultValue: multiple ? [] : undefined
  });
  const contentJSX = /*#__PURE__*/_jsx(Space, {
    ...omit(restProps, ['value', 'defaultValue', 'onChange']),
    direction: "horizontal",
    children: options.map(item => {
      const selected = multiple ? (value || []).indexOf(item.value) > -1 : value === item.value;
      return /*#__PURE__*/_jsx(ButtonOption, {
        theme: theme,
        type: type,
        round: round,
        text: item.label,
        badge: item.badge,
        disabled: item.disabled,
        activeHighlight: activeHighlight,
        active: selected,
        onPress: () => {
          if (!editable) {
            return;
          }
          if (multiple) {
            const oldValue = value || [];
            const _value = oldValue.filter(v => v !== item.value);
            const newValue = _value.length === oldValue.length ? [item.value, ...oldValue] : _value;
            const newOptions = newValue.map(v => {
              const optionIndex = options.findIndex(o => o.value === v);
              return {
                ...options[optionIndex]
              };
            });
            onChange(newValue, newOptions);
          } else {
            if (item.value === value) {
              if (deselect) {
                onChange(null, []);
              }
            } else {
              onChange(item.value, options.filter(o => o.value === item.value));
            }
          }
        }
      }, `${item.value}`);
    })
  });
  if (scrollable && !restProps.wrap) {
    return /*#__PURE__*/_jsx(ScrollView, {
      horizontal: true,
      bouncesZoom: false,
      showsHorizontalScrollIndicator: false,
      children: contentJSX
    });
  }
  return contentJSX;
}
export default ButtonOptionGroup;
//# sourceMappingURL=button-option-group.js.map