"use strict";

import Color from 'color';
import isNil from 'lodash/isNil';
import React, { isValidElement, memo, useMemo } from 'react';
import { View, TouchableOpacity, StyleSheet } from 'react-native';
import { renderTextLikeJSX } from "../helpers/index.js";
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const ButtonOption = ({
  theme,
  active,
  activeHighlight = true,
  badge,
  type = 'hazy',
  text,
  textStyle,
  size = 's',
  hairline,
  round = false,
  style,
  children,
  ...restProps
}) => {
  const [CV, STYLES, TOKENS] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const inactiveBackgroundColor = useMemo(() => {
    if (type === 'outline') {
      return TOKENS.white;
    }
    if (type === 'white') {
      return TOKENS.white;
    }
    return TOKENS.gray_2;
  }, [TOKENS.gray_2, TOKENS.white, type]);
  const inactiveBorderColor = useMemo(() => {
    if (restProps.disabled) {
      if (type === 'white') {
        return TOKENS.white;
      }
      return CV.button_option_disabled_border_color;
    }
    if (type === 'outline') {
      return TOKENS.gray_5;
    }
    if (type === 'white') {
      return TOKENS.white;
    }
    return inactiveBackgroundColor;
  }, [CV.button_option_disabled_border_color, TOKENS.gray_5, TOKENS.white, inactiveBackgroundColor, restProps.disabled, type]);
  const activeBackgroundColor = useMemo(() => Color(CV.button_primary_color).fade(0.89).string(), [CV.button_primary_color]);
  const buttonStyles = [STYLES.button, STYLES.option, {
    height: CV[`button_${size}_height`],
    backgroundColor: active && activeHighlight ? activeBackgroundColor : inactiveBackgroundColor,
    borderColor: active ? CV.button_primary_color : inactiveBorderColor,
    borderWidth: hairline ? StyleSheet.hairlineWidth : 1
  }, STYLES[`button_${size}_padding_horizontal`], round ? STYLES.button_round : null, restProps.disabled ? STYLES.button_disabled : null, style];
  const childrenJSX = /*#__PURE__*/isValidElement(children) ? children : renderTextLikeJSX(!isNil(children) ? children : text, [{
    color: restProps.disabled ? CV.button_option_disabled_text_color : active && activeHighlight ? CV.button_primary_color : TOKENS.gray_8,
    fontSize: CV[`button_${size}_font_size`]
  }, textStyle]);
  const badgeTextJSX = renderTextLikeJSX(badge, [STYLES.option_badge_text]);
  const badgeJSX = !isNil(badgeTextJSX) ? /*#__PURE__*/_jsx(View, {
    style: STYLES.option_badge,
    children: badgeTextJSX
  }) : null;
  return /*#__PURE__*/_jsxs(TouchableOpacity, {
    accessibilityRole: "button",
    ...restProps,
    activeOpacity: CV.button_active_opacity,
    style: buttonStyles,
    children: [childrenJSX, badgeJSX]
  });
};
export default /*#__PURE__*/memo(ButtonOption);
//# sourceMappingURL=button-option.js.map