"use strict";

import isNil from 'lodash/isNil';
import omit from 'lodash/omit';
import React, { memo } from 'react';
import { View, Text } from 'react-native';
import { getDefaultValue } from "../helpers/index.js";
import { useControllableValue } from "../hooks/index.js";
import Theme from "../theme/index.js";
import CheckboxIcon from "./checkbox-icon.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
function Checkbox({
  theme,
  labelTextStyle,
  iconStyle,
  activeValue = true,
  inactiveValue = false,
  label,
  labelDisabled = false,
  labelPosition = 'right',
  iconSize = 20,
  renderIcon,
  disabled,
  activeColor,
  gap,
  style,
  children,
  ...restProps
}) {
  if (disabled) {
    labelDisabled = disabled;
  }
  const [value, onChange] = useControllableValue(restProps, {
    defaultValue: inactiveValue
  });
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const _gap = getDefaultValue(gap, CV.checkbox_label_margin);
  const active = value === activeValue;
  const onChangeValue = () => {
    const newValue = active ? inactiveValue : activeValue;
    onChange(newValue);
  };
  const labelJSX = !isNil(label) ? /*#__PURE__*/_jsx(Text, {
    suppressHighlighting: true,
    style: [STYLES.label, {
      [labelPosition === 'left' ? 'marginRight' : 'marginLeft']: _gap
    }, disabled ? STYLES.label_disabled : null, labelTextStyle],
    onPress: labelDisabled ? undefined : onChangeValue,
    children: label
  }) : children;
  const iconProps = {
    style: iconStyle,
    active,
    activeColor,
    disabled,
    size: iconSize,
    onPress: onChangeValue
  };
  const iconJSX = renderIcon ? renderIcon(iconProps) : /*#__PURE__*/_jsx(CheckboxIcon, {
    testID: "CHECKBOX_ICON",
    ...iconProps
  });
  return /*#__PURE__*/_jsxs(View, {
    ...omit(restProps, ['value', 'defaultValue', 'onChange']),
    style: [STYLES.checkbox, style],
    children: [labelPosition === 'left' ? labelJSX : null, iconJSX, labelPosition === 'right' ? labelJSX : null]
  });
}
export default /*#__PURE__*/memo(Checkbox);
//# sourceMappingURL=checkbox.js.map