"use strict";

import React, { useState, useMemo, useEffect, memo } from 'react';
import { Keyboard } from 'react-native';
import { useSafeAreaInsets } from 'react-native-safe-area-context';
import Dialog from "./dialog.js";
import { jsx as _jsx } from "react/jsx-runtime";
const DialogKeyboard = ({
  style,
  safeAreaTop,
  ...restProps
}) => {
  const insets = useSafeAreaInsets();
  const [keyboardShow, setKeyboardShow] = useState(false);
  const dialogStyle = useMemo(() => ({
    position: 'absolute',
    top: safeAreaTop ?? insets.top
  }), [insets.top, safeAreaTop]);
  useEffect(() => {
    const keyboardDidShow = Keyboard.addListener('keyboardDidShow', () => {
      setKeyboardShow(true);
    });
    const keyboardDidHide = Keyboard.addListener('keyboardDidHide', () => {
      setKeyboardShow(false);
    });
    return () => {
      keyboardDidShow.remove();
      keyboardDidHide.remove();
    };
  }, []);
  return /*#__PURE__*/_jsx(Dialog, {
    ...restProps,
    style: keyboardShow ? style ? [dialogStyle, style] : dialogStyle : style
  });
};
export default /*#__PURE__*/memo(DialogKeyboard);
//# sourceMappingURL=dialog-keyboard.js.map