"use strict";

import React, { useEffect, memo } from 'react';
import { callInterceptor } from "../helpers/index.js";
import useState from "../hooks/useStateUpdate.js";
import Dialog from "./dialog.js";
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Dialog 弹出框
 * @description 配合函数的使用
 */
const DialogMethod = ({
  beforeClose,
  onResponse,
  ...restProps
}) => {
  const [state, setState] = useState({
    visible: false,
    cancel: false,
    confirm: false,
    overlay: false
  });
  const genOnPressBtn = action => () => {
    setState({
      [action]: true
    });
    callInterceptor(beforeClose, {
      args: [action],
      done: () => {
        onResponse?.(action);
        setState({
          [action]: false,
          visible: false
        });
      },
      canceled: () => {
        setState({
          [action]: false
        });
      }
    });
  };
  useEffect(() => {
    setState({
      visible: true
    });
  }, []);
  const onRequestClose = () => {
    genOnPressBtn('overlay')();
    return true;
  };
  const onPressClose = () => {
    setState({
      visible: false
    });
  };
  return /*#__PURE__*/_jsx(Dialog, {
    ...restProps,
    onRequestClose: onRequestClose,
    visible: state.visible,
    onPressConfirm: genOnPressBtn('confirm'),
    onPressCancel: genOnPressBtn('cancel'),
    onPressOverlay: genOnPressBtn('overlay'),
    cancelButtonLoading: state.cancel,
    confirmButtonLoading: state.confirm,
    onPressClose: onPressClose
  });
};
export default /*#__PURE__*/memo(DialogMethod);
//# sourceMappingURL=dialog-method.js.map