"use strict";

import isNil from 'lodash/isNil';
import React, { useMemo, memo } from 'react';
import { getDefaultValue } from "../helpers/index.js";
import { useControllableValue, usePersistFn } from "../hooks/index.js";
import useState from "../hooks/useStateUpdate.js";
import Locale from "../locale/index.js";
import { useDropdownConfig } from "./context.js";
import DropdownSelector from "./dropdown-selector.js";
import DropdownText from "./dropdown-text.js";
import { jsx as _jsx } from "react/jsx-runtime";
const DropdownItem = ({
  popupTestID,
  titleStyle,
  titleTextStyle,
  options,
  duration,
  zIndex,
  closeOnPressOutside,
  loading,
  placeholder = '',
  search,
  onSearch,
  cancellable,
  ...restProps
}) => {
  const locale = Locale.useLocale().DropdownItem;
  const config = useDropdownConfig();
  const [active, setActive] = useState(false);
  const [value, onChange] = useControllableValue(restProps);
  const _selectOption = useMemo(() => {
    if (loading) {
      const x = {
        label: locale.labelLoadingText,
        value: null
      };
      return x;
    }

    // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
    let selectOption = {};
    const findX = list => {
      list.forEach(item => {
        if (item.value === value) {
          selectOption = item;
        } else if (item.children?.length) {
          findX(item.children);
        }
      });
    };
    findX(options);
    return selectOption;
  }, [loading, locale.labelLoadingText, options, value]);
  duration = getDefaultValue(duration, config.duration);
  zIndex = getDefaultValue(zIndex, config.zIndex);
  closeOnPressOutside = getDefaultValue(closeOnPressOutside, config.closeOnPressOutside);
  const onPressText = usePersistFn(() => {
    // 计算 Menu 的 Top 和元素高度
    // eslint-disable-next-line max-params
    config.MenuRef.current?.measure((x, y, width, height, pageX, pageY) => {
      setActive(true);
      DropdownSelector({
        targetHeight: height,
        targetPageY: pageY,
        defaultValue: value,
        options,
        duration,
        zIndex,
        closeOnPressOutside,
        activeColor: config.activeColor,
        search,
        onSearch,
        cancellable,
        testID: popupTestID
      }).then(d => {
        onChange(d.value, d.data[0]);
      }).catch(() => {}).finally(() => {
        setActive(false);
      });
    });
  });
  return /*#__PURE__*/_jsx(DropdownText, {
    ...restProps,
    style: titleStyle,
    textStyle: titleTextStyle,
    title: !isNil(_selectOption.label) ? _selectOption.label : placeholder,
    badge: _selectOption.badge,
    active: active,
    onPress: onPressText,
    disabled: restProps.disabled || loading
  });
};
export default /*#__PURE__*/memo(DropdownItem);
//# sourceMappingURL=dropdown-item.js.map