"use strict";

import isNil from 'lodash/isNil';
import React, { useMemo, memo } from 'react';
import { getDefaultValue } from "../helpers/index.js";
import { useControllableValue, usePersistFn } from "../hooks/index.js";
import useState from "../hooks/useStateUpdate.js";
import Locale from "../locale/index.js";
import { useDropdownConfig } from "./context.js";
import DropdownSelector from "./dropdown-selector.js";
import DropdownText from "./dropdown-text.js";
import { jsx as _jsx } from "react/jsx-runtime";
const DropdownMultiple = ({
  popupTestID,
  titleStyle,
  titleTextStyle,
  options,
  duration,
  zIndex,
  closeOnPressOutside,
  loading,
  placeholder = '',
  beforeChecked,
  search,
  onSearch,
  cancellable,
  multipleMode,
  ...restProps
}) => {
  const locale = Locale.useLocale().DropdownItem;
  const config = useDropdownConfig();
  const [active, setActive] = useState(false);
  const [value, onChange] = useControllableValue(restProps);
  const _selectOptionLabel = useMemo(() => {
    if (loading) {
      return locale.labelLoadingText;
    }
    const _label = [];
    const findX = list => {
      list.forEach(item => {
        if (value?.indexOf(item.value) > -1) {
          _label.push(item.label);
        }
        if (item.children?.length) {
          findX(item.children);
        }
      });
    };
    findX(options);
    return _label.join('、');
  }, [loading, locale.labelLoadingText, options, value]);
  duration = getDefaultValue(duration, config.duration);
  zIndex = getDefaultValue(zIndex, config.zIndex);
  closeOnPressOutside = getDefaultValue(closeOnPressOutside, config.closeOnPressOutside);
  const onPressText = usePersistFn(() => {
    // 计算 Menu 的 Top 和元素高度
    // eslint-disable-next-line max-params
    config.MenuRef.current?.measure((x, y, width, height, pageX, pageY) => {
      setActive(true);
      DropdownSelector({
        targetHeight: height,
        targetPageY: pageY,
        defaultValue: !isNil(value) ? value : [],
        options,
        duration,
        zIndex,
        closeOnPressOutside,
        activeColor: config.activeColor,
        search,
        onSearch,
        cancellable,
        multiple: true,
        multipleMode,
        testID: popupTestID,
        beforeChecked
      }).then(d => {
        onChange(d.value, d.data);
      }).catch(() => {}).finally(() => {
        setActive(false);
      });
    });
  });
  return /*#__PURE__*/_jsx(DropdownText, {
    ...restProps,
    style: titleStyle,
    textStyle: titleTextStyle,
    title: !isNil(_selectOptionLabel) && !!_selectOptionLabel ? _selectOptionLabel : placeholder,
    active: active,
    onPress: onPressText,
    disabled: restProps.disabled || loading
  });
};
export default /*#__PURE__*/memo(DropdownMultiple);
//# sourceMappingURL=dropdown-multiple.js.map