"use strict";

import isNil from 'lodash/isNil';
import uniqBy from 'lodash/uniqBy';
import React, { useCallback, useMemo, useEffect, useState, memo } from 'react';
import { Text, Keyboard } from 'react-native';
import Button from "../button/index.js";
import ButtonBarConfirm from "../button-bar/button-bar-confirm.js";
import { getDefaultValue, isPromise } from "../helpers/index.js";
import { usePersistFn } from "../hooks/index.js";
import Locale from "../locale/index.js";
import Portal from "../portal/index.js";
import Space from "../space/index.js";
import Theme from "../theme/index.js";
import Tree from "../tree/index.js";
import { useDropdownConfig } from "./context.js";
import DropdownBadge from "./dropdown-badge.js";
import DropdownPopup from "./dropdown-popup.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const DropdownSelectorMethod = ({
  targetHeight,
  targetPageY,
  onConfirm,
  onCancel,
  defaultValue,
  options,
  duration,
  zIndex,
  closeOnPressOutside,
  onClosed,
  activeColor,
  beforeChecked,
  search,
  onSearch,
  cancellable,
  multiple,
  multipleMode,
  testID
}) => {
  const locale = Locale.useLocale().DropdownSelector;
  const {
    theme
  } = useDropdownConfig();
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const [CV_TREE] = Theme.useStyle({
    varCreator: Tree.varCreator
  });
  const [multipleValue, setMultipleValue] = useState(multiple ? defaultValue || [] : []);
  const allOptions = useMemo(() => {
    const findNode = op => {
      const ooo = [];
      op.forEach(o => {
        ooo.push(o);
        if (o.children?.length) {
          ooo.push(...findNode(o.children));
        }
      });
      return ooo;
    };
    return findNode(options);
  }, [options]);
  const _activeColor = getDefaultValue(activeColor, CV.dropdown_active_color);
  const [visible, setVisible] = useState(false);
  const treeOptions = useMemo(() => {
    const convertOption = ops => {
      const nodes = [];
      ops.forEach(item => {
        const _opt = {
          label: item.label,
          value: item.value,
          children: item.children?.length ? convertOption(item.children) : [],
          render: isNil(item.badge) ? undefined : p => {
            return /*#__PURE__*/_jsxs(Space, {
              direction: "horizontal",
              align: "center",
              style: STYLES.item_tree_item,
              children: [/*#__PURE__*/_jsx(Text, {
                style: [{
                  fontSize: CV_TREE.tree_item_text_font_size,
                  color: CV_TREE.tree_item_text_color
                }, p.labelHighlight ? {
                  color: p.activeColor
                } : null],
                numberOfLines: 1,
                children: p.label
              }), /*#__PURE__*/_jsx(DropdownBadge, {
                count: item.badge
              })]
            });
          }
        };
        nodes.push(_opt);
      });
      return nodes;
    };
    return convertOption(options);
  }, [CV_TREE.tree_item_text_color, CV_TREE.tree_item_text_font_size, STYLES.item_tree_item, options]);
  useEffect(() => {
    setVisible(true);
  }, []);
  const findNodeByValue = (tree, value) => {
    for (const item of tree) {
      if (item.value === value) {
        return item;
      }
      if (item.children) {
        const _v = findNodeByValue(item.children, value);
        if (_v) {
          return _v;
        }
      }
    }
    return undefined;
  };
  const onPressShade = useCallback(() => {
    setVisible(false);
    Keyboard.dismiss();
    onCancel?.();
  }, [onCancel]);
  const onRequestClose = usePersistFn(() => {
    onPressShade();
    return true;
  });
  const onChangePersistFn = usePersistFn((v, _, event) => {
    if (multiple) {
      if (beforeChecked) {
        const returnVal = beforeChecked({
          value: [],
          checked: event.checked,
          option: event.option
        });
        if (isPromise(returnVal)) {
          returnVal.then(nv => {
            setMultipleValue(mv => uniqBy(
            // eslint-disable-next-line max-nested-callbacks
            [...mv.filter(mvi => mvi !== event.option.value), ...nv],
            // eslint-disable-next-line max-nested-callbacks
            x => x));
          });
        } else {
          setMultipleValue(mv => uniqBy([...mv.filter(mvi => mvi !== event.option.value), ...returnVal], x => x));
        }
      } else {
        setMultipleValue(v);
      }
    } else {
      setVisible(false);
      Keyboard.dismiss();
      const _v = v;
      const _o = findNodeByValue(options, _v);
      onConfirm?.(_v, _o ? [_o] : []);
    }
  });
  const onConfirmMultiple = usePersistFn(() => {
    setVisible(false);
    Keyboard.dismiss();
    onConfirm?.(multipleValue, multipleValue.map(item => {
      return findNodeByValue(options, item);
    }));
  });
  return /*#__PURE__*/_jsxs(DropdownPopup, {
    testID: testID,
    targetHeight: targetHeight,
    targetPageY: targetPageY,
    closeOnPressOutside: closeOnPressOutside,
    duration: duration,
    zIndex: zIndex,
    onPressShade: onPressShade,
    visible: visible,
    onRequestClose: onRequestClose,
    onClosed: onClosed,
    onPressOverlay: onPressShade,
    children: [/*#__PURE__*/_jsx(Tree, {
      defaultExpandAll: true,
      activeColor: _activeColor,
      minHeight: false,
      search: search,
      options: treeOptions,
      onChange: onChangePersistFn,
      onSearch: onSearch,
      cancellable: cancellable,
      multiple: multiple,
      multipleMode: multipleMode,
      ...(multiple ? {
        value: multipleValue
      } : {
        defaultValue: defaultValue
      })
    }), multiple ? /*#__PURE__*/_jsx(ButtonBarConfirm, {
      safeAreaInsetBottom: false,
      cancel: [/*#__PURE__*/_jsx(Button, {
        type: "link",
        text: allOptions.length !== multipleValue.length ? locale.allButtonText : locale.notAllButtonText,
        onPress: () => {
          if (allOptions.length !== multipleValue.length) {
            setMultipleValue(allOptions.map(i => i.value));
          } else {
            setMultipleValue([]);
          }
        }
      }, "2"), /*#__PURE__*/_jsx(Button, {
        type: "hazy",
        text: locale.cancelButtonText,
        onPress: onPressShade
      }, "1")],
      children: /*#__PURE__*/_jsx(Button, {
        text: locale.confirmButtonText,
        onPress: onConfirmMultiple
      })
    }) : null]
  });
};
const DropdownSelectorMethodMemo = /*#__PURE__*/memo(DropdownSelectorMethod);
export default opt => {
  return new Promise((resolve, reject) => {
    const key = Portal.add(/*#__PURE__*/_jsx(DropdownSelectorMethodMemo, {
      ...opt,
      onCancel: () => {
        opt.onCancel?.();
        reject(new Error());
      },
      onConfirm: (v, d) => {
        opt.onConfirm?.(v, d);
        resolve({
          value: v,
          data: d
        });
      },
      onClosed: () => {
        Portal.remove(key);
      }
    }));
  });
};
//# sourceMappingURL=dropdown-selector.js.map