"use strict";

import isNil from 'lodash/isNil';
import omit from 'lodash/omit';
import React, { memo } from 'react';
import { StyleSheet, View, Text, TouchableOpacity } from 'react-native';
import { varCreator as varCreatorButton } from "../button/style.js";
import { getDefaultValue, getArrowOutline } from "../helpers/index.js";
import Theme from "../theme/index.js";
import { useDropdownConfig } from "./context.js";
import DropdownBadge from "./dropdown-badge.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
const DropdownText = ({
  textStyle,
  iconStyle,
  disabled = false,
  title,
  active = false,
  pressable = true,
  activeColor,
  direction,
  badge,
  // TouchableOpacity 属性
  style,
  activeOpacity,
  ...restProps
}) => {
  const config = useDropdownConfig();
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme: config.theme
  });
  const [CV_BUTTON] = Theme.useStyle({
    varCreator: varCreatorButton
  });
  const showBadge = !active && !isNil(badge) && badge !== false;

  // 修正数据
  activeColor = getDefaultValue(activeColor, config.activeColor);
  activeOpacity = getDefaultValue(activeOpacity, CV_BUTTON.button_active_opacity);
  direction = getDefaultValue(direction, config.direction);
  const textStyleFlatten = StyleSheet.flatten(textStyle) || {};
  const textColor = disabled ? CV.dropdown_text_disabled_color : active ? activeColor : textStyleFlatten.color || CV.dropdown_text_color;
  const itemStyles = [STYLES.text_item, config.titleStyle, style];
  const textStyles = [STYLES.text_text, showBadge ? null : STYLES.text_text_gap, config.titleTextStyle, {
    color: textColor
  }, omit(textStyleFlatten, ['color'])];
  const iconStyles = [config.iconStyle, iconStyle].filter(Boolean);
  const ArrowFill = getArrowOutline(active ? direction === 'up' ? 'down' : 'up' : direction);
  const ctxJSX = /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(View, {
      style: STYLES.text_text_container,
      children: /*#__PURE__*/_jsx(Text, {
        style: textStyles,
        numberOfLines: 1,
        children: title
      })
    }), showBadge ? /*#__PURE__*/_jsx(DropdownBadge, {
      count: badge,
      style: [STYLES.text_text_badge, STYLES.text_text_gap]
    }) : null, /*#__PURE__*/_jsx(ArrowFill, {
      style: iconStyles.length ? iconStyles : undefined,
      size: CV.dropdown_text_icon_size,
      color: active ? activeColor : CV.dropdown_text_icon_color
    })]
  });
  if (pressable) {
    return /*#__PURE__*/_jsx(TouchableOpacity, {
      ...restProps,
      disabled: disabled,
      style: itemStyles,
      activeOpacity: activeOpacity,
      children: ctxJSX
    });
  }
  return /*#__PURE__*/_jsx(View, {
    ...restProps,
    style: itemStyles,
    children: ctxJSX
  });
};
export default /*#__PURE__*/memo(DropdownText);
//# sourceMappingURL=dropdown-text.js.map