"use strict";

import React, { PureComponent } from 'react';
import Blank from "../blank/index.js";
import Button from "../button/index.js";
import Result from "../result/index.js";
import ResultIconError from "../result/icons/result-icon-error.js";
import { jsx as _jsx } from "react/jsx-runtime";
const ERROR_PAGE_STYLE = {
  flex: 1,
  backgroundColor: '#fff'
};

/**
 * ErrorBoundary 错误捕获
 * @description 一般用于应用根组件，捕获 React 内产生的问题。
 */
class ErrorBoundary extends PureComponent {
  static getDerivedStateFromError(error) {
    // 更新 state，下次渲染可以展示错误相关的 UI
    return {
      error
    };
  }
  state = {
    error: null
  };
  componentDidCatch(error, info) {
    this.props.onError?.(error, info);
  }

  /**
   * 点击清空错误，重新渲染子组件
   */
  onPressReload = () => {
    this.setState({
      error: null
    });
  };
  render() {
    if (this.state.error) {
      // 渲染出错时的 UI
      if (this.props.renderError) {
        return this.props.renderError({
          name: this.state.error.name,
          message: this.state.error.message,
          onReset: this.onPressReload
        });
      }
      return /*#__PURE__*/_jsx(Blank, {
        type: "padding",
        style: ERROR_PAGE_STYLE,
        children: /*#__PURE__*/_jsx(Result, {
          status: "error",
          renderIcon: () => /*#__PURE__*/_jsx(ResultIconError, {}),
          subtitle: `${this.props.title || '加载失败，请稍后再试~'}\n${this.state.error.name}\n${this.state.error.message}`,
          extra: /*#__PURE__*/_jsx(Button, {
            type: "primary",
            size: "s",
            text: this.props.reloadText || '重新加载',
            onPress: this.onPressReload
          })
        })
      });
    }
    return this.props.children;
  }
}
export default ErrorBoundary;
//# sourceMappingURL=index.js.map