"use strict";

import isUndefined from 'lodash/isUndefined';
import omit from 'lodash/omit';
import React, { useMemo, memo } from 'react';
import { Keyboard } from 'react-native';
import DatePicker from "../date-picker/index.js";
import { formatDate } from "../date-picker-view/helper.js";
import { useControllableValue, usePersistFn } from "../hooks/index.js";
import TextInputClear from "../text-input/text-input-clear.js";
import FieldText from "./field-text.js";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
const FieldDate = ({
  mode = 'Y-m',
  min,
  max,
  renderLabel,
  confirmButtonText,
  cancelButtonText,
  formatValueText,
  datePickerTitle,
  datePickerCustomOption,
  isLink = true,
  editable = true,
  clearable = false,
  ...restProps
}) => {
  const [value, onChange] = useControllableValue(restProps);
  const valueText = useMemo(() => value ? formatDate(mode, value) : undefined, [value, mode]);
  const onPress = usePersistFn(() => {
    Keyboard.dismiss();
    const option = {
      defaultValue: value || new Date(),
      confirmButtonText,
      cancelButtonText,
      mode,
      min,
      max,
      renderLabel,
      title: datePickerTitle
    };
    DatePicker(datePickerCustomOption ? datePickerCustomOption(option) : option).then(({
      action,
      value: _value
    }) => {
      if (action === 'confirm') {
        onChange(_value);
      }
    });
  });
  return /*#__PURE__*/_jsx(FieldText, {
    ...omit(restProps, ['value', 'defaultValue', 'onChange']),
    disabled: !editable,
    onPress: onPress,
    value: formatValueText && !isUndefined(valueText) && value ? formatValueText(value, mode, valueText) : valueText,
    isLink: value && clearable ? false : isLink,
    valueExtra: value && clearable ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [restProps.valueExtra, /*#__PURE__*/_jsx(TextInputClear, {
        onPress: () => {
          onChange(null);
        }
      })]
    }) : restProps.valueExtra
  });
};
export default /*#__PURE__*/memo(FieldDate);
//# sourceMappingURL=field-date.js.map