"use strict";

import isArray from 'lodash/isArray';
import isUndefined from 'lodash/isUndefined';
import React, { memo } from 'react';
import { Keyboard, View } from 'react-native';
import { varCreator as varCreatorCell } from "../cell/style.js";
import { usePersistFn } from "../hooks/index.js";
import LoadingSpinner from "../loading/loading-spinner.js";
import Locale from "../locale/index.js";
import Selector from "../selector/index.js";
import TextInputClear from "../text-input/text-input-clear.js";
import Theme from "../theme/index.js";
import FieldText from "./field-text.js";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * 输入框 选择输入
 */
const FieldSelector = ({
  value,
  options,
  multiple,
  onChange,
  optionsLoading = false,
  editable = true,
  clearable = false,
  selectorTitle,
  renderResultText,
  search,
  isLink = true,
  ...restProps
}) => {
  const locale = Locale.useLocale().FieldSelector;
  const TOKENS = Theme.useThemeTokens();
  const CV_CELL = Theme.createVar(TOKENS, varCreatorCell);
  const onPressCell = usePersistFn(() => {
    Keyboard.dismiss();
    if (editable) {
      Selector({
        title: selectorTitle ?? locale.selectorTitle,
        multiple,
        options,
        value,
        search,
        onChange
      }).catch(() => {});
    }
  });
  const hasValue = multiple ? isArray(value) && value.length > 0 : !isUndefined(value);
  const _value = hasValue ? multiple ? value : [value] : undefined;
  const _option = _value?.map(o => {
    const index = options.findIndex(ops => ops.value === o);
    if (index >= 0) {
      return options[index];
    }
    return null;
  }).filter(Boolean) ?? [];
  const value2text = hasValue ? renderResultText ? renderResultText(_value, _option) : _option.map(o => o.label).join('、') : undefined;
  return /*#__PURE__*/_jsx(FieldText, {
    ...restProps,
    onPress: optionsLoading ? undefined : onPressCell,
    value: value2text,
    isLink: optionsLoading || hasValue && clearable ? false : isLink,
    valueExtra: optionsLoading || hasValue && clearable ? /*#__PURE__*/_jsxs(_Fragment, {
      children: [restProps.valueExtra, optionsLoading ? /*#__PURE__*/_jsx(View
      // eslint-disable-next-line react-native/no-inline-styles
      , {
        style: {
          marginLeft: CV_CELL.cell_icon_link_margin_left,
          justifyContent: 'center',
          alignItems: 'center'
        },
        children: /*#__PURE__*/_jsx(LoadingSpinner, {
          testID: "FIELD_SELECTOR_LOADING",
          size: CV_CELL.cell_icon_size,
          color: CV_CELL.cell_icon_color
        })
      }) : /*#__PURE__*/_jsx(TextInputClear, {
        onPress: () => {
          // TODO 修复类型报错
          onChange?.(multiple ? [] : undefined, []);
        }
      })]
    }) : restProps.valueExtra
  });
};
export default /*#__PURE__*/memo(FieldSelector);
//# sourceMappingURL=field-selector.js.map