"use strict";

import RCForm from 'rc-field-form';
import React, { useImperativeHandle, forwardRef, useMemo } from 'react';
import { usePersistFn } from "../hooks/index.js";
import Toast from "../toast/index.js";
import { FormContext } from "./context.js";
import useForm from "./useForm.js";

/**
 * 默认处理错误的回调
 */
import { jsx as _jsx } from "react/jsx-runtime";
const defaultOnFinishFailed = errorInfo => {
  Toast(errorInfo.errorFields[0].errors[0]);
};
const InternalForm = ({
  onFinishFailed = defaultOnFinishFailed,
  form,
  onFinish,
  ...restProps
}, ref) => {
  const [wrapForm] = useForm(form);
  const value = useMemo(() => ({
    form: wrapForm
  }), [wrapForm]);
  useImperativeHandle(ref, () => wrapForm);
  const onFinishPersistFn = usePersistFn(() => {
    onFinish?.(wrapForm.getFieldsValue(true));
  });
  return /*#__PURE__*/_jsx(FormContext.Provider, {
    value: value,
    children: /*#__PURE__*/_jsx(RCForm, {
      ...restProps,
      component: false,
      form: wrapForm,
      onFinishFailed: onFinishFailed,
      onFinish: onFinishPersistFn
    })
  });
};
const Form = /*#__PURE__*/forwardRef(InternalForm);
export default Form;
//# sourceMappingURL=form.js.map