"use strict";

import React, { useRef, useMemo, memo } from 'react';
import { Animated } from 'react-native';
import { Svg, Circle } from 'react-native-svg';
import { getDefaultValue } from "../helpers/index.js";
import Theme from "../theme/index.js";
import { varCreator } from "./style.js";
import useLoop from "./useLoop.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const AnimatedCircle = Animated.createAnimatedComponent(Circle);
const STROKE_WIDTH = 2;
const Circular = ({
  theme,
  size,
  color,
  ...restProps
}) => {
  const [CV] = Theme.useStyle({
    varCreator,
    theme
  });
  const AnimatedCircle0Value = useRef(new Animated.Value(0)).current;
  const AnimatedCircle1Value = useRef(new Animated.Value(0)).current;
  const AnimatedCircle2Value = useRef(new Animated.Value(0)).current;
  let _size = getDefaultValue(size, CV.loading_icon_size);
  color = getDefaultValue(color, CV.loading_icon_color);
  const circle1Props = useMemo(() => {
    const center = Math.floor(_size / 2);
    const radios = Math.floor(center - STROKE_WIDTH / 2);
    return {
      cy: center,
      cx: center,
      r: radios
    };
  }, [_size]);
  const circle2Props = useMemo(() => {
    const center = Math.floor(_size / 2);
    const radios = Math.floor(center - STROKE_WIDTH / 2 - center / 2);
    return {
      cy: center,
      cx: center,
      r: radios
    };
  }, [_size]);
  const half1Circle = useMemo(() => circle1Props.r * Math.PI, [circle1Props.r]);
  const half2Circle = useMemo(() => circle2Props.r * Math.PI, [circle2Props.r]);
  useLoop(AnimatedCircle0Value, 0, {
    toValue: 1,
    duration: CV.loading_icon_animation_duration
  });
  useLoop(AnimatedCircle1Value, half1Circle, {
    toValue: -half1Circle * 2,
    duration: CV.loading_icon_animation_duration * 1.5
  });
  useLoop(AnimatedCircle2Value, half2Circle, {
    toValue: -half2Circle * 2,
    duration: CV.loading_icon_animation_duration * 2.5
  });
  const iconStyle = {
    justifyContent: 'center',
    alignItems: 'center',
    width: _size,
    height: _size,
    transform: [{
      rotateZ: AnimatedCircle0Value.interpolate({
        inputRange: [0, 1],
        outputRange: ['-90deg', '270deg']
      })
    }]
  };
  return /*#__PURE__*/_jsx(Animated.View, {
    ...restProps,
    style: [iconStyle, restProps.style],
    children: /*#__PURE__*/_jsxs(Svg, {
      width: "100%",
      height: "100%"
      // style={{ backgroundColor: 'rgba(0,0,0,0.2)' }}
      ,
      children: [/*#__PURE__*/_jsx(AnimatedCircle, {
        ...circle1Props,
        stroke: color,
        strokeWidth: STROKE_WIDTH,
        strokeDasharray: `${half1Circle},${half1Circle * 2}`,
        strokeLinecap: "round"
        // strokeDashoffset={half1Circle - half1Circle - half1Circle - 10}
        ,
        strokeDashoffset: AnimatedCircle1Value,
        fill: "none"
      }), /*#__PURE__*/_jsx(AnimatedCircle, {
        ...circle2Props,
        stroke: color,
        strokeWidth: STROKE_WIDTH,
        strokeDasharray: `${half2Circle},${half2Circle * 2}`,
        strokeLinecap: "round"
        // strokeDashoffset={half1Circle - half1Circle - half1Circle - 10}
        ,
        strokeDashoffset: AnimatedCircle2Value,
        fill: "none"
      })]
    })
  });
};
export default /*#__PURE__*/memo(Circular);
//# sourceMappingURL=loading-circular.js.map