"use strict";

import React, { useRef, memo, useEffect } from 'react';
import { View, Animated, StyleSheet, Easing } from 'react-native';
import { getDefaultValue } from "../helpers/index.js";
import Theme from "../theme/index.js";
import { varCreator } from "./style.js";
import { jsx as _jsx } from "react/jsx-runtime";
const PETAL_COUNT = 8;
const PETALS = new Array(PETAL_COUNT).fill(0);
const A_OPACITY = 1 / PETAL_COUNT;
const A_ROTATE = 360 / PETAL_COUNT;
const useLoop = (AnimatedValue, initValue, config) => {
  useEffect(() => {
    const spinAnimation = Animated.timing(AnimatedValue, {
      toValue: config.toValue,
      duration: config.duration,
      easing: config.easing,
      useNativeDriver: true
    });
    Animated.loop(spinAnimation).start();
  }, [AnimatedValue, initValue, config.duration, config.toValue, config.easing]);
};
const Spinner = ({
  theme,
  size,
  color,
  ...restProps
}) => {
  const [CV] = Theme.useStyle({
    varCreator,
    theme
  });
  const AnimatedSpinnerValue = useRef(new Animated.Value(0)).current;
  size = getDefaultValue(size, CV.loading_icon_size);
  color = getDefaultValue(color, CV.loading_icon_color);
  useLoop(AnimatedSpinnerValue, 0, {
    toValue: 1,
    duration: CV.loading_icon_animation_duration,
    easing: Easing.linear
  });
  return /*#__PURE__*/_jsx(Animated.View, {
    ...restProps,
    style: [STYLES.icon, {
      width: size,
      height: size,
      transform: [{
        rotateZ: AnimatedSpinnerValue.interpolate({
          inputRange: [0, 1],
          outputRange: ['0deg', '360deg']
        })
      }]
    }, restProps.style],
    children: PETALS.map((_, i) => {
      return /*#__PURE__*/_jsx(View, {
        style: StyleSheet.flatten([STYLES.petal, {
          opacity: A_OPACITY * (i + 1),
          transform: [{
            rotate: `${A_ROTATE * i}deg`
          }]
        }]),
        children: /*#__PURE__*/_jsx(View, {
          style: [STYLES.inner, {
            backgroundColor: color
          }]
        })
      }, i);
    })
  });
};
const STYLES = StyleSheet.create({
  icon: {
    justifyContent: 'center',
    alignItems: 'center',
    position: 'relative'
    // backgroundColor: '#999', // to test ui
    // transform: [
    //   {
    //     rotate: '-90deg',
    //   },
    // ],
  },
  petal: {
    position: 'absolute',
    left: 0,
    right: 0,
    top: 0,
    bottom: 0,
    alignItems: 'center'
    // backgroundColor: '#f30', // to test ui
  },
  inner: {
    width: 2,
    height: '30%'
    // 高版本 React Native Android 端会出现奇怪的截断
    // borderRadius: 1,
    // backgroundColor: '#000',
  }
});
export default /*#__PURE__*/memo(Spinner);
//# sourceMappingURL=loading-spinner.js.map