"use strict";

import { EyeOutline, EyeCloseOutline } from '@fruits-chain/icons-react-native';
import React, { useMemo, memo, forwardRef } from 'react';
import { getDefaultValue } from "../helpers/index.js";
import { useControllableValue, usePersistFn } from "../hooks/index.js";
import TextInput from "../text-input/index.js";
import Theme from "../theme/index.js";
import { jsx as _jsx } from "react/jsx-runtime";
const hitSlop = {
  top: 4,
  bottom: 4,
  left: 4,
  right: 4
};

/**
 * 密码输入
 */
const PasswordInput = /*#__PURE__*/forwardRef(({
  iconSize = 20,
  iconColor,
  ...restProps
}, ref) => {
  const TOKENS = Theme.useThemeTokens();
  const [secure, onChangeSecureTextEntry] = useControllableValue(restProps, {
    valuePropName: 'secureTextEntry',
    defaultValuePropName: 'defaultSecureTextEntry',
    defaultValue: true,
    trigger: 'onChangeSecureTextEntry'
  });
  iconColor = getDefaultValue(iconColor, TOKENS.gray_6);
  const iconStyle = useMemo(() => ({
    marginLeft: TOKENS.space_2
  }), [TOKENS.space_2]);
  const onPressIcon = usePersistFn(() => {
    onChangeSecureTextEntry(!secure);
  });
  const IconSuffix = secure ? EyeCloseOutline : EyeOutline;
  return /*#__PURE__*/_jsx(TextInput, {
    ...restProps,
    ref: ref,
    secureTextEntry: secure,
    suffix: /*#__PURE__*/_jsx(IconSuffix, {
      size: iconSize,
      color: iconColor,
      onPress: onPressIcon,
      style: iconStyle,
      hitSlop: hitSlop
    })
  });
});
export default /*#__PURE__*/memo(PasswordInput);
//# sourceMappingURL=index.js.map