"use strict";

import React, { useRef, useEffect, useMemo, memo } from 'react';
import { View, Text, FlatList } from 'react-native';
import { usePersistFn } from "../hooks/index.js";
import Theme from "../theme/index.js";
import { findUsableOptionIndex } from "./helper/column.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx } from "react/jsx-runtime";
const getSelectedIndex = n => n < 0 ? 0 : n;

/**
 * 选择器 列
 */
const PickerViewColumn = ({
  theme,
  itemHeight,
  visibleItemCount,
  options,
  value,
  onChange
}) => {
  const [, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const flatListRef = useRef(null);
  const LastTop = useRef(0);
  const paddedOptions = useMemo(() => {
    const array = [...options];
    for (let i = 0; i < (visibleItemCount - 1) / 2; i++) {
      array.unshift({
        value: '',
        label: ''
      });
      array.push({
        value: '',
        label: ''
      });
    }
    return array;
  }, [options, visibleItemCount]);
  const offsets = useMemo(() => [...Array(paddedOptions.length)].map((x, i) => i * itemHeight), [paddedOptions, itemHeight]);
  const selectedIndex = getSelectedIndex(options.findIndex(item => item.value === value));
  useEffect(() => {
    flatListRef.current?.scrollToIndex({
      index: selectedIndex,
      animated: false
    });
  }, [selectedIndex]);
  const onMomentumScrollEnd = usePersistFn(event => {
    const offsetY = Math.min(itemHeight * (options.length - 1), Math.max(event.nativeEvent.contentOffset.y, 0));
    let index = Math.floor(Math.floor(offsetY) / itemHeight);
    const last = Math.floor(offsetY % itemHeight);
    if (last > itemHeight / 2) {
      index++;
    }
    const isToNext = offsetY > LastTop.current;
    if (options[index].disabled) {
      index = findUsableOptionIndex(options, isToNext, index);
    }
    LastTop.current = offsetY;
    const selectOption = options[index];
    if (selectOption.value !== value) {
      onChange?.(selectOption);
    }
  });
  return /*#__PURE__*/_jsx(View, {
    style: STYLES.column,
    children: /*#__PURE__*/_jsx(FlatList
    // 当 options 刷新时重置组件，scrollToIndex 并不能完全可靠，借助 showsVerticalScrollIndicator 初始化视图
    , {
      ref: flatListRef,
      showsVerticalScrollIndicator: false,
      snapToOffsets: offsets,
      onMomentumScrollEnd: onMomentumScrollEnd,
      initialScrollIndex: selectedIndex,
      getItemLayout: (_, index) => ({
        length: itemHeight,
        offset: itemHeight * index,
        index
      }),
      decelerationRate: "fast",
      data: paddedOptions,
      keyExtractor: (_, index) => index.toString(),
      renderItem: ({
        item
      }) => {
        return /*#__PURE__*/_jsx(Text, {
          style: [STYLES.column_text, {
            height: itemHeight,
            lineHeight: itemHeight
          }, item.disabled ? STYLES.column_text_disabled : null],
          numberOfLines: 1,
          children: item.label
        }, item.value);
      }
    }, paddedOptions.map(item => item.value).join('_'))
  });
};
export default /*#__PURE__*/memo(PickerViewColumn);
//# sourceMappingURL=picker-view-column.js.map