"use strict";

import React, { useState, useEffect, useCallback, useRef, memo } from 'react';
import { callInterceptor } from "../helpers/index.js";
import { usePersistFn } from "../hooks/index.js";
import { getDataType, buildOptions, buildSelectedValue } from "../picker-view/helper/picker.js";
import Picker from "./picker.js";
import { jsx as _jsx } from "react/jsx-runtime";
const buildValue = (values, columns) => {
  const dataType = getDataType(columns);
  const [options] = buildOptions(dataType, columns, values);
  const [v, o] = buildSelectedValue(values, options);
  return {
    values: v,
    columns: o
  };
};
const PickerMethod = ({
  onCancel,
  onConfirm,
  onPressOverlay,
  beforeClose,
  ...restProps
}) => {
  const [visible, setVisible] = useState(false);
  const [loading, setLoading] = useState(false);
  const Value = useRef(buildValue(restProps.defaultValue || [], restProps.columns));
  useEffect(() => {
    setVisible(true);
  }, []);
  const onChange = useCallback((v, c) => {
    Value.current = {
      values: v,
      columns: c
    };
  }, []);
  const doAction = usePersistFn(action => {
    setLoading(true);
    callInterceptor(beforeClose, {
      args: [action, Value.current.values, Value.current.columns],
      done: () => {
        switch (action) {
          case 'cancel':
            onCancel?.(Value.current.values, Value.current.columns);
            break;
          case 'confirm':
            onConfirm?.(Value.current.values, Value.current.columns);
            break;
          case 'overlay':
            onPressOverlay?.(Value.current.values, Value.current.columns);
            break;
          default:
            break;
        }
        setLoading(false);
        setVisible(false);
      },
      canceled: () => {
        setLoading(false);
      }
    });
  });
  const onPressCancel = useCallback(() => {
    doAction('cancel');
  }, [doAction]);
  const onPressConfirm = useCallback(() => {
    doAction('confirm');
  }, [doAction]);
  const onPressPopupOverlay = useCallback(() => {
    doAction('overlay');
  }, [doAction]);
  const onRequestClose = useCallback(() => {
    onPressPopupOverlay();
    return true;
  }, [onPressPopupOverlay]);
  return /*#__PURE__*/_jsx(Picker, {
    ...restProps,
    visible: visible,
    onChange: onChange,
    onCancel: onPressCancel,
    onConfirm: onPressConfirm,
    onPressOverlay: onPressPopupOverlay,
    loading: loading,
    onRequestClose: onRequestClose
  });
};
export default /*#__PURE__*/memo(PickerMethod);
//# sourceMappingURL=picker-method.js.map