"use strict";

import omit from 'lodash/omit';
import pick from 'lodash/pick';
import React, { memo } from 'react';
import { Text, View } from 'react-native';
import { useSafeAreaInsets } from 'react-native-safe-area-context';
import Locale from "../locale/index.js";
import PickerView from "../picker-view/index.js";
import Popup from "../popup/index.js";
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const PICKER_VIEW_PROPS_KEYS = ['value', 'defaultValue', 'columns', 'loading', 'itemHeight', 'visibleItemCount', 'onChange'];
const Picker = ({
  theme,
  visible,
  title,
  confirmButtonText,
  cancelButtonText,
  toolbarPosition = 'top',
  showToolbar = true,
  onCancel,
  onConfirm,
  ...restProps
}) => {
  const locale = Locale.useLocale().Picker;
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const insets = useSafeAreaInsets();
  const headerTitleJSX = /*#__PURE__*/_jsx(Popup.Header, {
    showClose: false,
    title: title,
    leftExtra: /*#__PURE__*/_jsx(Text, {
      suppressHighlighting: true,
      style: STYLES.cancel_text,
      onPress: restProps.loading ? undefined : onCancel,
      children: cancelButtonText ?? locale.cancelButtonText
    }),
    rightExtra: /*#__PURE__*/_jsx(Text, {
      suppressHighlighting: true,
      style: STYLES.confirm_text,
      onPress: restProps.loading ? undefined : onConfirm,
      children: confirmButtonText ?? locale.confirmButtonText
    })
  });
  const pickerViewProps = pick(restProps, PICKER_VIEW_PROPS_KEYS);
  const popupProps = omit(restProps, PICKER_VIEW_PROPS_KEYS);
  return /*#__PURE__*/_jsxs(Popup, {
    ...popupProps,
    visible: visible,
    position: "bottom",
    round: true,
    children: [showToolbar && toolbarPosition === 'top' ? headerTitleJSX : null, /*#__PURE__*/_jsx(PickerView, {
      ...pickerViewProps
    }), showToolbar && toolbarPosition === 'bottom' ? headerTitleJSX : null, /*#__PURE__*/_jsx(View, {
      style: {
        height: insets.bottom + CV.picker_bottom_gap
      }
    })]
  });
};
export default /*#__PURE__*/memo(Picker);
//# sourceMappingURL=picker.js.map