"use strict";

import noop from 'lodash/noop';
import React, { useState, useRef, useCallback, useMemo, memo, isValidElement, Children, cloneElement } from 'react';
import { ScrollView, TouchableOpacity } from 'react-native';
import RNPopoverView from 'react-native-popover-view';
import { varCreator as varCreatorButton } from "../button/style.js";
import { getDefaultValue } from "../helpers/index.js";
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
const arrowSize = {
  width: 0,
  height: 0
};
const Popover = ({
  children,
  theme,
  content,
  dark = false,
  shadow = false,
  arrow = true,
  triggerStyle,
  onSelect = noop,
  disabled,
  renderContentComponent,
  duration,
  trigger = 'onPress',
  backgroundStyle,
  popoverStyle,
  ...restProps
}) => {
  const [, STYLES, TOKENS] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const [CV_BUTTON] = Theme.useStyle({
    varCreator: varCreatorButton
  });
  duration = getDefaultValue(duration, TOKENS.animation_duration_base);
  const touchable = useRef(null);
  const [showPopover, setShowPopover] = useState(false);
  const animationConfig = useMemo(() => ({
    duration
  }), [duration]);
  const openPopover = useCallback(() => {
    setShowPopover(true);
  }, []);
  const closePopover = useCallback(() => {
    setShowPopover(false);
  }, []);
  const _onSelect = (value, index) => {
    if (onSelect) {
      onSelect(value, index);
    }
    closePopover();
  };
  const renderContent = () => {
    const items = Children.map(content, (child, index) => {
      if (! /*#__PURE__*/isValidElement(child)) {
        return child;
      }
      return /*#__PURE__*/cloneElement(child, {
        onSelect: v => _onSelect(v, index),
        dark: dark
      });
    });
    if (typeof renderContentComponent === 'function') {
      return renderContentComponent(items, closePopover);
    }
    return /*#__PURE__*/_jsx(ScrollView, {
      children: items
    });
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(TouchableOpacity, {
      ref: touchable,
      onPress: trigger === 'onPress' ? openPopover : undefined,
      onLongPress: trigger === 'onLongPress' ? openPopover : undefined,
      onPressIn: trigger === 'onPressIn' ? openPopover : undefined,
      style: [STYLES.trigger, triggerStyle],
      disabled: disabled,
      activeOpacity: CV_BUTTON.button_active_opacity,
      children: children
    }), /*#__PURE__*/_jsx(RNPopoverView, {
      ...restProps,
      from: touchable,
      isVisible: showPopover,
      backgroundStyle: [STYLES.background, backgroundStyle],
      popoverStyle: [STYLES.content,
      // Android 黑色背景的阴影也是黑色，不友好
      dark ? STYLES.content_dark : null, shadow ? STYLES.content_shadow : null, popoverStyle],
      arrowSize: !arrow ? arrowSize : undefined,
      onRequestClose: closePopover,
      animationConfig: animationConfig,
      children: renderContent()
    })]
  });
};
export default /*#__PURE__*/memo(Popover);
//# sourceMappingURL=popover.js.map