"use strict";

/* eslint-disable @typescript-eslint/explicit-member-accessibility */
/* eslint-disable @typescript-eslint/consistent-type-definitions */
import React, { Component } from 'react';
import PortalConsumer from "./portal-consumer.js";
import PortalHost, { portal, PortalContext } from "./portal-host.js";
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * Portal allows to render a component at a different place in the parent tree.
 * You can use it to render content which should appear above other elements, similar to `Modal`.
 * It requires a `Portal.Host` component to be rendered somewhere in the parent tree.
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { Text } from 'react-native';
 * import { Portal } from '@fruits-chain/react-native-xiaoshu';
 *
 * export default class MyComponent extends React.Component {
 *   render() {
 *     const { visible } = this.state;
 *     return (
 *       <Portal>
 *         <Text>This is rendered at a different place</Text>
 *       </Portal>
 *     );
 *   }
 * }
 * ```
 */
class Portal extends Component {
  static Host = PortalHost;
  static add = portal.add;
  static remove = portal.remove;
  render() {
    const {
      children
    } = this.props;
    return /*#__PURE__*/_jsx(PortalContext.Consumer, {
      children: manager => /*#__PURE__*/_jsx(PortalConsumer, {
        manager: manager,
        children: children
      })
    });
  }
}
export default Portal;
//# sourceMappingURL=portal.js.map