"use strict";

import React, { useState, useCallback, useEffect, memo, isValidElement } from 'react';
import { View, Text, StyleSheet } from 'react-native';
import Button from "../button/index.js";
import { getDefaultValue } from "../helpers/index.js";
import { usePersistFn } from "../hooks/index.js";
import Locale from "../locale/index.js";
import Result from "../result/index.js";
import Space from "../space/index.js";
import Theme from "../theme/index.js";
import Progress from "./progress.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
const ProgressPage = ({
  children,
  theme,
  loading: loadingOut,
  backgroundColor,
  defaultPercentage = 10,
  fail,
  failMessage,
  failIcon,
  onPressReload,
  refreshText,
  failExtra,
  extraLoading,
  overlayZIndex = 1000,
  syncRenderChildren = false
}) => {
  const locale = Locale.useLocale().ProgressPage;
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  backgroundColor = getDefaultValue(backgroundColor, CV.progress_page_background_color);
  const [state, setState] = useState({
    loading: loadingOut,
    percentage: defaultPercentage,
    duration: 0,
    animated: false
  });
  const onAnimationEnd = useCallback(n => {
    if (n === 100) {
      // 延迟更改状态更顺畅，进度条是完整走完的
      setTimeout(() => {
        setState(s => ({
          ...s,
          loading: false
        }));
      }, 0);
    }
  }, []);
  const onPressReloadPersistFn = usePersistFn(() => {
    onPressReload?.();
  });
  useEffect(() => {
    setState(s => {
      const isReload = !s.loading && loadingOut;
      if (isReload) {
        return {
          ...s,
          loading: loadingOut,
          percentage: defaultPercentage,
          duration: 0,
          animated: false
        };
      }
      return {
        ...s
      };
    });
  }, [defaultPercentage, loadingOut]);
  useEffect(() => {
    // 做一个延迟，避免上下两次操作状态合并在一个中，reload 的时候丢失过渡状态
    setTimeout(() => {
      setState(s => {
        return {
          ...s,
          percentage: loadingOut ? 90 : 100,
          duration: loadingOut ? 1500 : 100,
          animated: true
        };
      });
    }, 0);
  }, [loadingOut]);
  const placeholderStyle = {
    flex: 1,
    backgroundColor: backgroundColor
  };
  const placeholderJSX = state.loading ? /*#__PURE__*/_jsxs(View, {
    style: placeholderStyle,
    children: [/*#__PURE__*/_jsx(Progress, {
      percentage: state.percentage,
      showPivot: false,
      animated: state.animated,
      animationDuration: state.duration,
      onAnimationEnd: onAnimationEnd,
      square: true
    }), extraLoading]
  }) : null;
  const errorJSX = !state.loading && fail ? /*#__PURE__*/_jsx(Result, {
    style: STYLES.fail_page,
    status: "warning",
    subtitle: /*#__PURE__*/_jsxs(Space, {
      head: true,
      gap: "l",
      align: "center",
      children: [/*#__PURE__*/isValidElement(failMessage) ? failMessage : /*#__PURE__*/_jsx(Text, {
        style: STYLES.text,
        children: failMessage ?? locale.failMessage
      }), onPressReload ? /*#__PURE__*/_jsx(Button, {
        style: STYLES.btn,
        text: refreshText ?? locale.labelRefreshText,
        onPress: onPressReloadPersistFn
      }) : null, failExtra]
    }),
    renderIcon: () => {
      if (failIcon) {
        return failIcon;
      }
      return /*#__PURE__*/_jsx(Result.IconWarning, {});
    }
  }) : null;
  if (syncRenderChildren) {
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [children, state.loading || fail ? /*#__PURE__*/_jsxs(View, {
        style: {
          ...StyleSheet.absoluteFillObject,
          zIndex: overlayZIndex
        },
        children: [placeholderJSX, errorJSX]
      }) : null]
    });
  }
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [!loadingOut && !state.loading && !fail ? children : null, placeholderJSX, errorJSX]
  });
};
export default /*#__PURE__*/memo(ProgressPage);
//# sourceMappingURL=progress-page.js.map