"use strict";

import React, { useState, useCallback, useRef, useEffect, memo } from 'react';
import { View, Text, Animated } from 'react-native';
import { getDefaultValue } from "../helpers/index.js";
import * as helpers from "../helpers/index.js";
import { usePersistFn } from "../hooks/index.js";
import Theme from "../theme/index.js";
import { varCreator } from "./style.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * Progress 进度条
 */
const Progress = ({
  testID,
  theme,
  percentage = 0,
  pivotText,
  color,
  trackColor,
  pivotColor,
  textColor,
  strokeHeight,
  inactive = false,
  showPivot = true,
  square = false,
  animated = false,
  animationDuration,
  onAnimationEnd
}) => {
  const AnimatedValue = useRef(new Animated.Value(0)).current;
  const StartPercentage = useRef(percentage);
  const onAnimationEndPersistFn = usePersistFn(n => {
    onAnimationEnd?.(n);
  });
  const [CV,, TOKENS] = Theme.useStyle({
    varCreator,
    theme
  });

  // 默认值
  color = getDefaultValue(color, CV.progress_color);
  if (inactive) {
    color = '#cacaca';
  }
  trackColor = getDefaultValue(trackColor, CV.progress_background_color);
  pivotColor = getDefaultValue(pivotColor, color);
  textColor = getDefaultValue(textColor, CV.progress_pivot_text_color);
  pivotText = getDefaultValue(pivotText, `${percentage}%`);
  strokeHeight = getDefaultValue(strokeHeight, CV.progress_height);
  animationDuration = getDefaultValue(animationDuration, TOKENS.animation_duration_base);
  const borderRadius = square ? 0 : strokeHeight / 2;
  const [progressLayout, setProgressLayout] = useState({
    width: 0,
    height: 0
  });
  const [textLayout, setTextLayout] = useState({
    width: 0,
    height: 0
  });
  useEffect(() => {
    const action = Animated.timing(AnimatedValue, {
      toValue: progressLayout.width * percentage / 100,
      duration: animated ? animationDuration : 0,
      easing: helpers.easing.easeInCubic,
      useNativeDriver: false
    });
    action.start(({
      finished
    }) => {
      if (finished) {
        onAnimationEndPersistFn(percentage);
      }
    });
    return () => {
      action.stop();
    };
  }, [AnimatedValue, percentage, animationDuration, progressLayout.width, animated, onAnimationEndPersistFn]);
  const barStyle = {
    position: 'absolute',
    left: 0,
    top: 0,
    width: AnimatedValue,
    height: strokeHeight,
    backgroundColor: color,
    borderRadius: borderRadius
  };
  const textBoxStyle = {
    position: 'absolute',
    left: AnimatedValue,
    top: 0,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: pivotColor,
    paddingHorizontal: CV.progress_pivot_padding_horizontal,
    borderRadius: TOKENS.border_radius_max,
    transform: [{
      translateX: -textLayout.width / 2
    }, {
      translateY: -(textLayout.height - strokeHeight) / 2
    }]
  };
  const onLayoutProgress = useCallback(e => {
    AnimatedValue.setValue(e.nativeEvent.layout.width * StartPercentage.current / 100);
    setProgressLayout(e.nativeEvent.layout);
  }, [AnimatedValue]);
  const onLayoutText = useCallback(e => {
    setTextLayout(e.nativeEvent.layout);
  }, []);
  return /*#__PURE__*/_jsxs(View, {
    testID: testID,
    onLayout: onLayoutProgress,
    style: {
      height: strokeHeight,
      backgroundColor: trackColor,
      borderRadius: borderRadius
    },
    children: [/*#__PURE__*/_jsx(Animated.View, {
      style: barStyle
    }), showPivot ? /*#__PURE__*/_jsx(Animated.View, {
      onLayout: onLayoutText,
      style: textBoxStyle,
      children: /*#__PURE__*/_jsx(Text, {
        style: {
          color: textColor,
          fontSize: CV.progress_pivot_font_size,
          lineHeight: CV.progress_pivot_line_height_scale * CV.progress_pivot_font_size
        },
        children: pivotText
      })
    }) : null]
  });
};
export default /*#__PURE__*/memo(Progress);
//# sourceMappingURL=progress.js.map