"use strict";

import { CrossOutline, SuccessOutline, WarningOutline } from '@fruits-chain/icons-react-native';
import React, { memo } from 'react';
import { View } from 'react-native';
import { renderTextLikeJSX } from "../helpers/index.js";
import Space from "../space/index.js";
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const renderStatusIcon = (status, size) => {
  const props = {
    size,
    color: '#fff'
  };
  switch (status) {
    case 'success':
      return /*#__PURE__*/_jsx(SuccessOutline, {
        ...props
      });
    case 'warning':
    case 'info':
      return /*#__PURE__*/_jsx(WarningOutline, {
        ...props
      });
    case 'error':
      return /*#__PURE__*/_jsx(CrossOutline, {
        ...props
      });
    default:
      return null;
  }
};

/**
 * Result结果
 * @description 用于反馈一系列操作任务的处理结果。
 */
const Result = ({
  theme,
  subtitleTextStyle,
  titleTextStyle,
  title,
  subtitle,
  extra,
  renderIcon,
  status,
  ...restProps
}) => {
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const color = CV[`result_${status}_color`];
  const iconSize = CV.result_icon_size / 4 * 3;
  const iconJSX = renderIcon ? renderIcon(color, iconSize) : /*#__PURE__*/_jsx(View, {
    style: [STYLES.icon, {
      backgroundColor: color
    }],
    children: renderStatusIcon(status, iconSize)
  });
  const titleJSX = renderTextLikeJSX(title, [STYLES.titleText, titleTextStyle]);
  const subtitleJSX = renderTextLikeJSX(subtitle, [STYLES.subtitleText, subtitleTextStyle]);
  return /*#__PURE__*/_jsxs(Space, {
    ...restProps,
    children: [iconJSX, titleJSX, subtitleJSX, extra]
  });
};
export default /*#__PURE__*/memo(Result);
//# sourceMappingURL=result.js.map