"use strict";

import { ArrowLeftOutline, SearchOutline } from '@fruits-chain/icons-react-native';
import isUndefined from 'lodash/isUndefined';
import noop from 'lodash/noop';
import React, { useRef, useCallback, memo, forwardRef } from 'react';
import { View } from 'react-native';
import Button from "../button/index.js";
import { getDefaultValue } from "../helpers/index.js";
import { usePersistFn, useDebounceFn } from "../hooks/index.js";
import Locale from "../locale/index.js";
import TextInput from "../text-input/index.js";
import { varCreator as varCreatorTextInput } from "../text-input/style.js";
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";

/**
 * 搜索
 */
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
const Search = /*#__PURE__*/forwardRef(({
  theme,
  iconSize = 20,
  iconColor,
  onSearch,
  showBack = false,
  onPressBack,
  autoSearch = false,
  showSearchButton = true,
  onSearchDebounceWait = 300,
  searchText,
  extra,
  prefix,
  suffix,
  value,
  defaultValue,
  placeholder,
  placeholderTextColor,
  autoFocus,
  onChangeText,
  style,
  ...restProps
}, ref) => {
  const locale = Locale.useLocale().Search;
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const [CV_TEXT_INPUT] = Theme.useStyle({
    varCreator: varCreatorTextInput
  });
  const onChangeTextPersistFn = usePersistFn(onChangeText || noop);
  const {
    run: runOnSearch
  } = useDebounceFn(onSearch || noop, {
    wait: onSearchDebounceWait,
    leading: false,
    trailing: true
  });

  /** 输入框内部的值，不维护状态，避免没必要的更新 */
  const SearchText = useRef(!isUndefined(value) ? value : defaultValue);
  placeholderTextColor = getDefaultValue(placeholderTextColor, CV_TEXT_INPUT.text_input_placeholder_text_color);
  iconColor = getDefaultValue(iconColor, placeholderTextColor);
  const onChange = useCallback(v => {
    SearchText.current = v;
    if (autoSearch) {
      runOnSearch(v);
    }
  }, [autoSearch, runOnSearch]);
  const _onChangeText = useCallback(v => {
    SearchText.current = v;
    onChangeTextPersistFn(v);
    if (autoSearch) {
      runOnSearch(v);
    }
  }, [autoSearch, onChangeTextPersistFn, runOnSearch]);
  const onPress = useCallback(() => {
    runOnSearch(SearchText.current);
  }, [runOnSearch]);

  // TextInput value、defaultValue 对值进行了判断，影响 clearable
  // 此处对两个属性的 undefined 情况进行过滤，useControllableValue 能正确识别是否受控
  const textInputProps = {
    ...(isUndefined(value) ? {} : {
      value
    }),
    ...(isUndefined(defaultValue) ? {} : {
      defaultValue
    })
  };
  return /*#__PURE__*/_jsxs(View, {
    ...restProps,
    style: [STYLES.search, showBack ? STYLES.search_back : null, style],
    children: [showBack ? /*#__PURE__*/_jsx(ArrowLeftOutline, {
      onPress: onPressBack,
      color: CV.search_back_icon_color,
      size: 24,
      style: STYLES.icon_back
    }) : null, /*#__PURE__*/_jsx(TextInput, {
      ref: ref,
      ...textInputProps,
      clearable: true,
      fixGroupStyle: STYLES.text_input_group,
      style: STYLES.text_input,
      placeholder: placeholder,
      placeholderTextColor: placeholderTextColor,
      prefix: /*#__PURE__*/_jsxs(_Fragment, {
        children: [prefix, /*#__PURE__*/_jsx(SearchOutline, {
          color: iconColor,
          size: iconSize
        })]
      }),
      suffix: suffix,
      onChange: onChange,
      onChangeText: _onChangeText,
      autoFocus: autoFocus
    }), showSearchButton ? /*#__PURE__*/_jsx(Button, {
      text: searchText ?? locale.searchText,
      type: "primary",
      style: STYLES.search_btn,
      size: "s",
      onPress: onPress
    }) : null, extra]
  });
});
export default /*#__PURE__*/memo(Search);
//# sourceMappingURL=search.js.map