"use strict";

import React, { memo, useRef, useMemo } from 'react';
import { ScrollView, View } from 'react-native';
import Theme from "../theme/index.js";
import { maxSteps, StepsContext } from "./context.js";
import Step from "./step.js";
import { varCreator, styleCreator } from "./style.js";
import { jsx as _jsx } from "react/jsx-runtime";
const Steps = ({
  current,
  data,
  style,
  theme
}) => {
  const [, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const ctx = useMemo(() => ({
    current,
    data
  }), [current, data]);
  const scrollRef = useRef(null);
  const setScrollDistance = width => {
    if (scrollRef.current && data && data.length > maxSteps) {
      scrollRef.current.scrollTo({
        x: width / data.length * (current - 1 > 0 ? current - 1 : 0),
        y: 0
      });
    }
  };
  const inner = data && data.length > 0 ? /*#__PURE__*/_jsx(View, {
    style: [STYLES.stepsBox, style],
    onLayout: e => {
      setScrollDistance(e?.nativeEvent?.layout?.width);
    },
    children: /*#__PURE__*/_jsx(StepsContext.Provider, {
      value: ctx,
      children: data?.map((v, i) => {
        return /*#__PURE__*/_jsx(Step, {
          index: i,
          theme: theme,
          ...v
        }, i);
      })
    })
  }) : null;
  return /*#__PURE__*/_jsx(View, {
    style: STYLES.outWrap,
    children: data && data.length > maxSteps ? /*#__PURE__*/_jsx(ScrollView, {
      style: STYLES.scrollViewBox,
      horizontal: true,
      ref: scrollRef,
      children: inner
    }) : inner
  });
};
export default /*#__PURE__*/memo(Steps);
//# sourceMappingURL=steps.js.map