"use strict";

import { CrossOutline } from '@fruits-chain/icons-react-native';
import Color from 'color';
import isNil from 'lodash/isNil';
import React, { memo, useMemo } from 'react';
import { TouchableOpacity, View, Text, StyleSheet } from 'react-native';
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";

/**
 * Tag 标签
 */
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const Tag = ({
  children,
  style,
  theme,
  innerStyle,
  closable = false,
  onClose,
  size = 'm',
  type = 'primary',
  visible = true,
  closeIcon,
  icon,
  color,
  textColor,
  hairline,
  ...restProps
}) => {
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const mainColor = !isNil(color) ? color : CV.tag_primary_color;
  const {
    innerTypeStyle,
    textTypeStyle
  } = useMemo(() => {
    const tempInnerStyle = {};
    const tempTextStyle = {};
    switch (type) {
      case 'primary':
        {
          tempInnerStyle.backgroundColor = mainColor;
          tempInnerStyle.borderColor = mainColor;
          tempTextStyle.color = CV.tag_text_color;
          break;
        }
      case 'ghost':
        {
          tempInnerStyle.backgroundColor = CV.tag_ghost_background_color;
          tempInnerStyle.borderColor = mainColor;
          tempInnerStyle.borderWidth = hairline ? StyleSheet.hairlineWidth : 1;
          tempTextStyle.color = mainColor;
          break;
        }
      case 'hazy':
        {
          const hazyColor = Color(mainColor).lightness(CV.tag_hazy_lightness).hex();
          tempInnerStyle.backgroundColor = hazyColor;
          tempInnerStyle.borderColor = hazyColor;
          tempTextStyle.color = mainColor;
          break;
        }
      default:
        break;
    }
    return {
      innerTypeStyle: tempInnerStyle,
      textTypeStyle: tempTextStyle
    };
  }, [CV.tag_text_color, CV.tag_ghost_background_color, CV.tag_hazy_lightness, hairline, type, mainColor]);
  const {
    innerSizeStyle,
    textSizeStyle
  } = useMemo(() => {
    const tempInnerStyle = STYLES[`tag_inner_${size}`];
    const tempTextStyle = STYLES[`tag_text_${size}`];
    return {
      innerSizeStyle: tempInnerStyle,
      textSizeStyle: tempTextStyle
    };
  }, [STYLES, size]);
  const textStyle = StyleSheet.flatten([/** 类型样式 */
  textTypeStyle, textSizeStyle, /** 外部样式 */
  !isNil(textColor) && {
    color: textColor
  }]);

  // 关闭的图标
  const renderCloseIcon = () => {
    if (closable) {
      return closeIcon ? /*#__PURE__*/_jsx(TouchableOpacity, {
        onPress: onClose,
        children: closeIcon
      }) : /*#__PURE__*/_jsx(CrossOutline, {
        onPress: onClose,
        size: CV[`tag_${size}_close_icon`],
        color: textStyle.color
      });
    }
    return null;
  };
  if (visible) {
    return /*#__PURE__*/_jsx(View, {
      ...restProps,
      style: [STYLES.tag, style],
      children: /*#__PURE__*/_jsxs(View, {
        style: [/** 类型样式 */
        STYLES.tag_inner, innerTypeStyle, innerSizeStyle, innerStyle],
        children: [icon, /*#__PURE__*/_jsx(Text, {
          style: textStyle,
          children: children
        }), renderCloseIcon()]
      })
    });
  }
  return null;
};
export default /*#__PURE__*/memo(Tag);
//# sourceMappingURL=tag.js.map