"use strict";

import { useMemo } from 'react';
import useOriginalDeepCopy from "../hooks/useOriginalDeepCopy.js";
import { createStyle } from "./create-style.js";
import { createVar } from "./create-var.js";
import { useThemeTokens } from "./theme.js";
export const useStyle = ({
  theme,
  varCreator,
  styleCreator
}) => {
  const TOKENS = useThemeTokens();
  const cv = createVar(TOKENS, varCreator);
  const cvMerge = useOriginalDeepCopy({
    ...cv,
    ...theme
  });
  const styles = useMemo(() => {
    if (styleCreator) {
      if (theme) {
        return styleCreator(cvMerge, TOKENS);
      }
      return createStyle(cv, styleCreator, TOKENS);
    }
    // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
    return {};
  }, [TOKENS, cv, cvMerge, styleCreator, theme]);
  return [cvMerge, styles, TOKENS];
};
//# sourceMappingURL=useStyle.js.map