"use strict";

import { PlusOutline } from '@fruits-chain/icons-react-native';
import isNil from 'lodash/isNil';
import React, { isValidElement } from 'react';
import { View, Text, Image } from 'react-native';
import { usePersistFn } from "../hooks/index.js";
import Locale from "../locale/index.js";
import Theme from "../theme/index.js";
import { varCreator, styleCreator } from "./style.js";
import UploaderImage from "./uploader-image.js";
import useImageLayout from "./useImageLayout.js";

/**
 * Uploader 文件上传
 */
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const Uploader = ({
  theme,
  list,
  maxCount = Number.MAX_SAFE_INTEGER,
  imageComponent = Image,
  deletable = true,
  showUpload = true,
  uploadText,
  uploadIcon,
  onPressUpload,
  colCount = 4,
  colGap = 'm',
  onPressImage,
  onPressDelete,
  onPressError,
  style,
  onLayout,
  ...restProps
}) => {
  const locale = Locale.useLocale().Uploader;
  const [CV, STYLES] = Theme.useStyle({
    varCreator,
    styleCreator,
    theme
  });
  const [onLayoutWrapper, getSizeImage, getMarginImage] = useImageLayout();
  const onLayoutView = usePersistFn(e => {
    onLayoutWrapper(e);
    onLayout?.(e);
  });
  const onPressUploadPersistFn = usePersistFn(() => {
    onPressUpload?.();
  });
  const genOnPressDelete = (item, index) => () => {
    onPressDelete?.(item, index, list);
  };
  const genOnPressImage = (item, index) => () => {
    const onPressCallback = item.status === 'error' ? onPressError : onPressImage;
    onPressCallback?.(item, index, list);
  };
  const showUploadButton = showUpload && list.length < maxCount;
  const imageGap = typeof colGap === 'number' ? colGap : CV[`uploader_image_gap_${colGap}`];
  const imageSize = getSizeImage(colCount, imageGap);
  const total = (showUploadButton ? 1 : 0) + list.length;
  return /*#__PURE__*/_jsxs(View, {
    ...restProps,
    style: style ? [STYLES.uploader, style] : STYLES.uploader,
    onLayout: onLayoutView,
    children: [list.map((item, index) => {
      return /*#__PURE__*/_jsx(UploaderImage, {
        filepath: item.filepath,
        status: item.status,
        imageComponent: imageComponent,
        deletable: isNil(item.deletable) ? deletable : item.deletable,
        size: imageSize,
        marginRight: getMarginImage(total, colCount, index).marginRight ? imageGap : undefined,
        marginBottom: getMarginImage(total, colCount, index).marginBottom ? imageGap : undefined,
        onPress: genOnPressImage(item, index),
        onPressDelete: genOnPressDelete(item, index)
      }, item.key);
    }), showUpload && list.length < maxCount ? /*#__PURE__*/_jsxs(UploaderImage, {
      isUpload: true,
      size: imageSize,
      marginBottom: getMarginImage(total, colCount, total - 1).marginBottom ? imageGap : undefined,
      onPress: onPressUploadPersistFn,
      children: [/*#__PURE__*/isValidElement(uploadIcon) ? uploadIcon : /*#__PURE__*/_jsx(PlusOutline, {
        color: CV.uploader_upload_text_color,
        pointerEvents: "none"
      }), /*#__PURE__*/_jsx(Text, {
        style: STYLES.upload_text,
        children: uploadText ?? locale.uploadText
      })]
    }) : null]
  });
};
export default Uploader;
//# sourceMappingURL=uploader.js.map