import React, { Component } from 'react';
import type { EmitterSubscription } from 'react-native';
import PortalManager from './portal-manager';
export type PortalHostProps = {
    children: React.ReactNode;
};
export type Operation = {
    type: 'mount';
    key: number;
    children: React.ReactNode;
} | {
    type: 'update';
    key: number;
    children: React.ReactNode;
} | {
    type: 'unmount';
    key: number;
};
export type PortalMethods = {
    mount: (children: React.ReactNode) => number;
    update: (key: number, children: React.ReactNode) => void;
    unmount: (key: number) => void;
};
export declare const PortalContext: React.Context<PortalMethods>;
declare class PortalGuard {
    private nextKey;
    add: (e: React.ReactNode) => number;
    remove: (key: number) => void;
}
/**
 * portal
 */
export declare const portal: PortalGuard;
/**
 * Portal host renders all of its children `Portal` elements.
 * For example, you can wrap a screen in `Portal.Host` to render items above the screen.
 * If you're using the `Provider` component, it already includes `Portal.Host`.
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { Text } from 'react-native';
 * import { Portal } from '@fruits-chain/react-native-xiaoshu';
 *
 * export default class MyComponent extends React.Component {
 *   render() {
 *     return (
 *       <Portal.Host>
 *         <Text>Content of the app</Text>
 *       </Portal.Host>
 *     );
 *   }
 * }
 * ```
 *
 * Here any `Portal` elements under `<App />` are rendered alongside `<App />` and will appear above `<App />` like a `Modal`.
 */
export default class PortalHost extends Component<PortalHostProps> {
    static displayName: string;
    nextKey: number;
    queue: Operation[];
    manager: PortalManager | undefined | null;
    addTypeEmitter: EmitterSubscription;
    removeTypeEmitter: EmitterSubscription;
    componentDidMount(): void;
    componentWillUnmount(): void;
    setManager: (manager?: PortalManager | undefined | null) => void;
    mount: (children: React.ReactNode, _key?: number) => number;
    update: (key: number, children: React.ReactNode) => void;
    unmount: (key: number) => void;
    render(): React.JSX.Element;
}
export {};
//# sourceMappingURL=portal-host.d.ts.map